--
-- ============LICENSE_START=======================================================
-- Copyright (C) 2024 Ericsson
-- Modifications Copyright (C) 2024 OpenInfra Foundation Europe
-- ================================================================================
-- Licensed under the Apache License, Version 2.0 (the "License");
-- you may not use this file except in compliance with the License.
-- You may obtain a copy of the License at
--
--       http://www.apache.org/licenses/LICENSE-2.0
--
-- Unless required by applicable law or agreed to in writing, software
-- distributed under the License is distributed on an "AS IS" BASIS,
-- WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
-- See the License for the specific language governing permissions and
-- limitations under the License.
--
-- SPDX-License-Identifier: Apache-2.0
-- ============LICENSE_END=========================================================
--

CREATE EXTENSION IF NOT EXISTS postgis;
CREATE EXTENSION IF NOT EXISTS postgis_topology;

GRANT USAGE ON SCHEMA topology to :pguser;
GRANT SELECT ON ALL SEQUENCES IN SCHEMA topology TO :pguser;
GRANT SELECT ON ALL TABLES IN SCHEMA topology TO :pguser;

CREATE SCHEMA IF NOT EXISTS ties_data;
ALTER SCHEMA ties_data OWNER TO :pguser;
SET default_tablespace = '';
SET default_table_access_method = heap;

SET ROLE :pguser;

-- Function to create CONSTRAINT only if it does not exists
CREATE OR REPLACE FUNCTION ties_data.create_constraint_if_not_exists (
	t_name TEXT, c_name TEXT, constraint_sql TEXT
)
RETURNS void AS
$$
BEGIN
	IF NOT EXISTS (SELECT constraint_name FROM information_schema.table_constraints WHERE table_name = t_name AND constraint_name = c_name) THEN
		EXECUTE constraint_sql;
	END IF;
END;
$$ language 'plpgsql';

CREATE TABLE IF NOT EXISTS ties_data."ef701af8e1445ed5d377664ba1d3d1c645e31639" (
	"id"			VARCHAR(511),
	"CD_sourceIds"			jsonb,
	"CD_classifiers"			jsonb,
	"CD_decorators"			jsonb,
	"name"			TEXT,
	"REL_FK_C2F5EC33C0760F653CE7263A49C0B697FCA2D542"			VARCHAR(511)
);

ALTER TABLE ONLY ties_data."ef701af8e1445ed5d377664ba1d3d1c645e31639" ALTER COLUMN "CD_sourceIds" SET DEFAULT '[]';
ALTER TABLE ONLY ties_data."ef701af8e1445ed5d377664ba1d3d1c645e31639" ALTER COLUMN "CD_classifiers" SET DEFAULT '[]';
ALTER TABLE ONLY ties_data."ef701af8e1445ed5d377664ba1d3d1c645e31639" ALTER COLUMN "CD_decorators" SET DEFAULT '{}';

CREATE TABLE IF NOT EXISTS ties_data."fa2dceaf53e045c136ce9db9bc5faae65a29fa4d" (
	"id"			VARCHAR(511),
	"CD_sourceIds"			jsonb,
	"CD_classifiers"			jsonb,
	"CD_decorators"			jsonb,
	"fdn"			TEXT,
	"cmId"			jsonb,
	"REL_FK_26958E3A529C4C8B68A29FDA906F8CD290F66078"			VARCHAR(511),
	"REL_ID_B7945BFD83380F3E12CF99F2B0F838F364027F92"			VARCHAR(511),
	"REL_CD_B7945BFD83380F3E12CF99F2B0F838F364027F92"			jsonb,
	"REL_CD_BF4AAC1A1A910D1182505CABF55BAAE822B2BE59"			jsonb,
	"REL_CD_AE82DD80D666B52D79A314F8B4EE9B046830D009"			jsonb
);

ALTER TABLE ONLY ties_data."fa2dceaf53e045c136ce9db9bc5faae65a29fa4d" ALTER COLUMN "CD_sourceIds" SET DEFAULT '[]';
ALTER TABLE ONLY ties_data."fa2dceaf53e045c136ce9db9bc5faae65a29fa4d" ALTER COLUMN "CD_classifiers" SET DEFAULT '[]';
ALTER TABLE ONLY ties_data."fa2dceaf53e045c136ce9db9bc5faae65a29fa4d" ALTER COLUMN "CD_decorators" SET DEFAULT '{}';

ALTER TABLE ONLY ties_data."fa2dceaf53e045c136ce9db9bc5faae65a29fa4d" ALTER COLUMN "REL_CD_B7945BFD83380F3E12CF99F2B0F838F364027F92" SET DEFAULT '[]';
ALTER TABLE ONLY ties_data."fa2dceaf53e045c136ce9db9bc5faae65a29fa4d" ALTER COLUMN "REL_CD_BF4AAC1A1A910D1182505CABF55BAAE822B2BE59" SET DEFAULT '[]';
ALTER TABLE ONLY ties_data."fa2dceaf53e045c136ce9db9bc5faae65a29fa4d" ALTER COLUMN "REL_CD_AE82DD80D666B52D79A314F8B4EE9B046830D009" SET DEFAULT '{}';

CREATE TABLE IF NOT EXISTS ties_data."5f8facd51b2bbddc90d9dee9be697907441892d0" (
	"id"			VARCHAR(511),
	"CD_sourceIds"			jsonb,
	"CD_classifiers"			jsonb,
	"CD_decorators"			jsonb,
	"name"			TEXT,
	"REL_FK_AB87B417CCD05C332DDD0C60F0C6AB41D38B05E5"			VARCHAR(511),
	"REL_ID_FC2F6A5A12917357B548C83F4B0C1AD58FA61413"			VARCHAR(511),
	"REL_CD_CEAD4CCE5250E7D3C64801C8FDDC21F1D87BEC0C"			jsonb,
	"REL_CD_744530EF4EB1D281D23ADB3DB4CC926DFBE7A60D"			jsonb,
	"REL_CD_4D1F8113C3096B383582A7A04E68974983B4259E"			jsonb,
	"REL_FK_8C98B70070BBD11F90F192DDA3ECF6302390E956"			VARCHAR(511),
	"REL_ID_AFBF10D23507AD3B6408947D2A9AF8465BA7B08C"			VARCHAR(511),
	"REL_CD_F7E43E0D0F76D6EFED9AB684B84A69E177F591D2"			jsonb,
	"REL_CD_C4349BB0F0292A3CE7E456E3A4C40C86DD6B15DF"			jsonb,
	"REL_CD_8AD499BB116F3213C079F643D4B3532035D092D2"			jsonb
);

ALTER TABLE ONLY ties_data."5f8facd51b2bbddc90d9dee9be697907441892d0" ALTER COLUMN "CD_sourceIds" SET DEFAULT '[]';
ALTER TABLE ONLY ties_data."5f8facd51b2bbddc90d9dee9be697907441892d0" ALTER COLUMN "CD_classifiers" SET DEFAULT '[]';
ALTER TABLE ONLY ties_data."5f8facd51b2bbddc90d9dee9be697907441892d0" ALTER COLUMN "CD_decorators" SET DEFAULT '{}';

ALTER TABLE ONLY ties_data."5f8facd51b2bbddc90d9dee9be697907441892d0" ALTER COLUMN "REL_CD_CEAD4CCE5250E7D3C64801C8FDDC21F1D87BEC0C" SET DEFAULT '[]';
ALTER TABLE ONLY ties_data."5f8facd51b2bbddc90d9dee9be697907441892d0" ALTER COLUMN "REL_CD_744530EF4EB1D281D23ADB3DB4CC926DFBE7A60D" SET DEFAULT '[]';
ALTER TABLE ONLY ties_data."5f8facd51b2bbddc90d9dee9be697907441892d0" ALTER COLUMN "REL_CD_4D1F8113C3096B383582A7A04E68974983B4259E" SET DEFAULT '{}';

ALTER TABLE ONLY ties_data."5f8facd51b2bbddc90d9dee9be697907441892d0" ALTER COLUMN "REL_CD_F7E43E0D0F76D6EFED9AB684B84A69E177F591D2" SET DEFAULT '[]';
ALTER TABLE ONLY ties_data."5f8facd51b2bbddc90d9dee9be697907441892d0" ALTER COLUMN "REL_CD_C4349BB0F0292A3CE7E456E3A4C40C86DD6B15DF" SET DEFAULT '[]';
ALTER TABLE ONLY ties_data."5f8facd51b2bbddc90d9dee9be697907441892d0" ALTER COLUMN "REL_CD_8AD499BB116F3213C079F643D4B3532035D092D2" SET DEFAULT '{}';

CREATE TABLE IF NOT EXISTS ties_data."300672c8a708d6af0b9af2f9accdff5e6e005721" (
	"id"			VARCHAR(511),
	"CD_sourceIds"			jsonb,
	"CD_classifiers"			jsonb,
	"CD_decorators"			jsonb,
	"020335B0F627C169E24167748C38FE756FB34AE2"			BIGINT,
	"nRTAC"			BIGINT,
	"nRPCI"			BIGINT,
	"cmId"			jsonb,
	"fdn"			TEXT,
	"nCI"			BIGINT,
	"REL_FK_609963BFEE15FF824280FBE201313C3CDACDDDCE"			VARCHAR(511),
	"REL_ID_040FC8B06B420BA5708AF4798102D1E65FB4DC61"			VARCHAR(511),
	"REL_CD_040FC8B06B420BA5708AF4798102D1E65FB4DC61"			jsonb,
	"REL_CD_66AEF506899F14F936A2F48F9444E2202F5D43F9"			jsonb,
	"REL_CD_022F8280C0739C614C5F3293E7D8D349A8A10E30"			jsonb
);

ALTER TABLE ONLY ties_data."300672c8a708d6af0b9af2f9accdff5e6e005721" ALTER COLUMN "CD_sourceIds" SET DEFAULT '[]';
ALTER TABLE ONLY ties_data."300672c8a708d6af0b9af2f9accdff5e6e005721" ALTER COLUMN "CD_classifiers" SET DEFAULT '[]';
ALTER TABLE ONLY ties_data."300672c8a708d6af0b9af2f9accdff5e6e005721" ALTER COLUMN "CD_decorators" SET DEFAULT '{}';

ALTER TABLE ONLY ties_data."300672c8a708d6af0b9af2f9accdff5e6e005721" ALTER COLUMN "REL_CD_040FC8B06B420BA5708AF4798102D1E65FB4DC61" SET DEFAULT '[]';
ALTER TABLE ONLY ties_data."300672c8a708d6af0b9af2f9accdff5e6e005721" ALTER COLUMN "REL_CD_66AEF506899F14F936A2F48F9444E2202F5D43F9" SET DEFAULT '[]';
ALTER TABLE ONLY ties_data."300672c8a708d6af0b9af2f9accdff5e6e005721" ALTER COLUMN "REL_CD_022F8280C0739C614C5F3293E7D8D349A8A10E30" SET DEFAULT '{}';

CREATE TABLE IF NOT EXISTS ties_data."bc563e4310b0538e6bdd35f52684160af5b23671" (
	"id"			VARCHAR(511),
	"name"			TEXT,
	"CD_sourceIds"			jsonb,
	"CD_classifiers"			jsonb,
	"CD_decorators"			jsonb
);

ALTER TABLE ONLY ties_data."bc563e4310b0538e6bdd35f52684160af5b23671" ALTER COLUMN "CD_sourceIds" SET DEFAULT '[]';
ALTER TABLE ONLY ties_data."bc563e4310b0538e6bdd35f52684160af5b23671" ALTER COLUMN "CD_classifiers" SET DEFAULT '[]';
ALTER TABLE ONLY ties_data."bc563e4310b0538e6bdd35f52684160af5b23671" ALTER COLUMN "CD_decorators" SET DEFAULT '{}';

CREATE TABLE IF NOT EXISTS ties_data."3fdb9cd7557edf559a0e4de88df220e7545884b5" (
	"id"			VARCHAR(511),
	"CD_sourceIds"			jsonb,
	"CD_classifiers"			jsonb,
	"CD_decorators"			jsonb,
	"gNBDUId"			BIGINT,
	"cmId"			jsonb,
	"3786A6CA64C9422F9E7FC35B7B039F345BBDDA65"			TEXT,
	"gNBIdLength"			INTEGER,
	"dUpLMNId"			jsonb,
	"gNBId"			BIGINT,
	"REL_FK_48B14FA5B787C6398AD1DE5EE670AD0D2A2CB36F"			VARCHAR(511),
	"REL_ID_BDE0B6C74D14AC109D29A08D80E92D4D0DCAEB0B"			VARCHAR(511),
	"REL_CD_45E8E8693B1B8928376EAA8995D08AA7B1E483BD"			jsonb,
	"REL_CD_7E9F11EFBF8974D7C7DAB02E181A0BE4148091C6"			jsonb,
	"REL_CD_FFF7E036187A7605BFC714483D2E60FD2FF6560B"			jsonb
);

ALTER TABLE ONLY ties_data."3fdb9cd7557edf559a0e4de88df220e7545884b5" ALTER COLUMN "CD_sourceIds" SET DEFAULT '[]';
ALTER TABLE ONLY ties_data."3fdb9cd7557edf559a0e4de88df220e7545884b5" ALTER COLUMN "CD_classifiers" SET DEFAULT '[]';
ALTER TABLE ONLY ties_data."3fdb9cd7557edf559a0e4de88df220e7545884b5" ALTER COLUMN "CD_decorators" SET DEFAULT '{}';

ALTER TABLE ONLY ties_data."3fdb9cd7557edf559a0e4de88df220e7545884b5" ALTER COLUMN "REL_CD_45E8E8693B1B8928376EAA8995D08AA7B1E483BD" SET DEFAULT '[]';
ALTER TABLE ONLY ties_data."3fdb9cd7557edf559a0e4de88df220e7545884b5" ALTER COLUMN "REL_CD_7E9F11EFBF8974D7C7DAB02E181A0BE4148091C6" SET DEFAULT '[]';
ALTER TABLE ONLY ties_data."3fdb9cd7557edf559a0e4de88df220e7545884b5" ALTER COLUMN "REL_CD_FFF7E036187A7605BFC714483D2E60FD2FF6560B" SET DEFAULT '{}';

CREATE TABLE IF NOT EXISTS ties_data."f86057a8762a50b1c7fb07af9d5c001bffaefd15" (
	"id"			VARCHAR(511),
	"aSide_B0FD0521695A211BFF76F413A31F28CBA32E57ED"			VARCHAR(511),
	"bSide_84EF1134719BB6FCF33A94FF770311FC722BCF41"			VARCHAR(511),
	"CD_sourceIds"			jsonb,
	"CD_classifiers"			jsonb,
	"CD_decorators"			jsonb
);

ALTER TABLE ONLY ties_data."f86057a8762a50b1c7fb07af9d5c001bffaefd15" ALTER COLUMN "CD_sourceIds" SET DEFAULT '[]';
ALTER TABLE ONLY ties_data."f86057a8762a50b1c7fb07af9d5c001bffaefd15" ALTER COLUMN "CD_classifiers" SET DEFAULT '[]';
ALTER TABLE ONLY ties_data."f86057a8762a50b1c7fb07af9d5c001bffaefd15" ALTER COLUMN "CD_decorators" SET DEFAULT '{}';

CREATE TABLE IF NOT EXISTS ties_data."5b8a47d4a8297a0a1d31e091af06e26d25ef6caf" (
	"id"			VARCHAR(511),
	"aSide_AntennaCapability"			VARCHAR(511),
	"bSide_AntennaModule"			VARCHAR(511),
	"CD_sourceIds"			jsonb,
	"CD_classifiers"			jsonb,
	"CD_decorators"			jsonb
);

ALTER TABLE ONLY ties_data."5b8a47d4a8297a0a1d31e091af06e26d25ef6caf" ALTER COLUMN "CD_sourceIds" SET DEFAULT '[]';
ALTER TABLE ONLY ties_data."5b8a47d4a8297a0a1d31e091af06e26d25ef6caf" ALTER COLUMN "CD_classifiers" SET DEFAULT '[]';
ALTER TABLE ONLY ties_data."5b8a47d4a8297a0a1d31e091af06e26d25ef6caf" ALTER COLUMN "CD_decorators" SET DEFAULT '{}';

CREATE TABLE IF NOT EXISTS ties_data."88f1bd76c7a935fb505cf235e6819f46c55ec98a" (
	"id"			VARCHAR(511),
	"CD_sourceIds"			jsonb,
	"CD_classifiers"			jsonb,
	"CD_decorators"			jsonb,
	"eUtranFqBands"			jsonb,
	"fdn"			TEXT,
	"geranFqBands"			jsonb,
	"nRFqBands"			jsonb,
	"cmId"			jsonb,
	"REL_FK_used-by-lteSectorCarrier"			VARCHAR(511)
);

ALTER TABLE ONLY ties_data."88f1bd76c7a935fb505cf235e6819f46c55ec98a" ALTER COLUMN "CD_sourceIds" SET DEFAULT '[]';
ALTER TABLE ONLY ties_data."88f1bd76c7a935fb505cf235e6819f46c55ec98a" ALTER COLUMN "CD_classifiers" SET DEFAULT '[]';
ALTER TABLE ONLY ties_data."88f1bd76c7a935fb505cf235e6819f46c55ec98a" ALTER COLUMN "CD_decorators" SET DEFAULT '{}';

CREATE TABLE IF NOT EXISTS ties_data."f8caf5ebe876c3001d67efe06e4d83abf0babe31" (
	"id"			VARCHAR(511),
	"totalTilt"			BIGINT,
	"cmId"			jsonb,
	"antennaBeamWidth"			jsonb,
	"positionWithinSector"			TEXT,
	"geo-location"			geography,
	"mechanicalAntennaBearing"			BIGINT,
	"fdn"			TEXT,
	"electricalAntennaTilt"			BIGINT,
	"mechanicalAntennaTilt"			BIGINT,
	"antennaModelNumber"			TEXT,
	"CD_sourceIds"			jsonb,
	"CD_classifiers"			jsonb,
	"CD_decorators"			jsonb,
	"REL_FK_grouped-by-sector"			VARCHAR(511),
	"REL_ID_SECTOR_GROUPS_ANTENNAMODULE"			VARCHAR(511),
	"REL_CD_sourceIds_SECTOR_GROUPS_ANTENNAMODULE"			jsonb,
	"REL_CD_classifiers_SECTOR_GROUPS_ANTENNAMODULE"			jsonb,
	"REL_CD_decorators_SECTOR_GROUPS_ANTENNAMODULE"			jsonb,
	"REL_FK_installed-at-site"			VARCHAR(511),
	"REL_ID_ANTENNAMODULE_INSTALLED_AT_SITE"			VARCHAR(511),
	"REL_CD_sourceIds_ANTENNAMODULE_INSTALLED_AT_SITE"			jsonb,
	"REL_CD_classifiers_ANTENNAMODULE_INSTALLED_AT_SITE"			jsonb,
	"REL_CD_decorators_ANTENNAMODULE_INSTALLED_AT_SITE"			jsonb
);

ALTER TABLE ONLY ties_data."f8caf5ebe876c3001d67efe06e4d83abf0babe31" ALTER COLUMN "CD_sourceIds" SET DEFAULT '[]';
ALTER TABLE ONLY ties_data."f8caf5ebe876c3001d67efe06e4d83abf0babe31" ALTER COLUMN "CD_classifiers" SET DEFAULT '[]';
ALTER TABLE ONLY ties_data."f8caf5ebe876c3001d67efe06e4d83abf0babe31" ALTER COLUMN "CD_decorators" SET DEFAULT '{}';

ALTER TABLE ONLY ties_data."f8caf5ebe876c3001d67efe06e4d83abf0babe31" ALTER COLUMN "REL_CD_sourceIds_SECTOR_GROUPS_ANTENNAMODULE" SET DEFAULT '[]';
ALTER TABLE ONLY ties_data."f8caf5ebe876c3001d67efe06e4d83abf0babe31" ALTER COLUMN "REL_CD_classifiers_SECTOR_GROUPS_ANTENNAMODULE" SET DEFAULT '[]';
ALTER TABLE ONLY ties_data."f8caf5ebe876c3001d67efe06e4d83abf0babe31" ALTER COLUMN "REL_CD_decorators_SECTOR_GROUPS_ANTENNAMODULE" SET DEFAULT '{}';

ALTER TABLE ONLY ties_data."f8caf5ebe876c3001d67efe06e4d83abf0babe31" ALTER COLUMN "REL_CD_sourceIds_ANTENNAMODULE_INSTALLED_AT_SITE" SET DEFAULT '[]';
ALTER TABLE ONLY ties_data."f8caf5ebe876c3001d67efe06e4d83abf0babe31" ALTER COLUMN "REL_CD_classifiers_ANTENNAMODULE_INSTALLED_AT_SITE" SET DEFAULT '[]';
ALTER TABLE ONLY ties_data."f8caf5ebe876c3001d67efe06e4d83abf0babe31" ALTER COLUMN "REL_CD_decorators_ANTENNAMODULE_INSTALLED_AT_SITE" SET DEFAULT '{}';

CREATE TABLE IF NOT EXISTS ties_data."5123d0adfb7b4a04e7f2e5e1783f476ed5cf76f6" (
	"id"			VARCHAR(511),
	"aSide_AntennaModule"			VARCHAR(511),
	"bSide_AntennaModule"			VARCHAR(511),
	"CD_sourceIds"			jsonb,
	"CD_classifiers"			jsonb,
	"CD_decorators"			jsonb
);

ALTER TABLE ONLY ties_data."5123d0adfb7b4a04e7f2e5e1783f476ed5cf76f6" ALTER COLUMN "CD_sourceIds" SET DEFAULT '[]';
ALTER TABLE ONLY ties_data."5123d0adfb7b4a04e7f2e5e1783f476ed5cf76f6" ALTER COLUMN "CD_classifiers" SET DEFAULT '[]';
ALTER TABLE ONLY ties_data."5123d0adfb7b4a04e7f2e5e1783f476ed5cf76f6" ALTER COLUMN "CD_decorators" SET DEFAULT '{}';

CREATE TABLE IF NOT EXISTS ties_data."cd39d44beed963d50df42cd301e63d288f911c97" (
	"id"			VARCHAR(511),
	"aSide_2A2D3374BF907674FA1905478E30ACB8882DC03C"			VARCHAR(511),
	"bSide_EE6DD4A2CFD743779BBCBFC18FC296EF6D72EB1E"			VARCHAR(511),
	"CD_sourceIds"			jsonb,
	"CD_classifiers"			jsonb,
	"CD_decorators"			jsonb
);

ALTER TABLE ONLY ties_data."cd39d44beed963d50df42cd301e63d288f911c97" ALTER COLUMN "CD_sourceIds" SET DEFAULT '[]';
ALTER TABLE ONLY ties_data."cd39d44beed963d50df42cd301e63d288f911c97" ALTER COLUMN "CD_classifiers" SET DEFAULT '[]';
ALTER TABLE ONLY ties_data."cd39d44beed963d50df42cd301e63d288f911c97" ALTER COLUMN "CD_decorators" SET DEFAULT '{}';

CREATE TABLE IF NOT EXISTS ties_data."c6f3a3396e9165e886da928c5fe1382fb20dc850" (
	"id"			VARCHAR(511),
	"aSide_2A2D3374BF907674FA1905478E30ACB8882DC03C"			VARCHAR(511),
	"bSide_EE6DD4A2CFD743779BBCBFC18FC296EF6D72EB1E"			VARCHAR(511),
	"CD_sourceIds"			jsonb,
	"CD_classifiers"			jsonb,
	"CD_decorators"			jsonb
);

ALTER TABLE ONLY ties_data."c6f3a3396e9165e886da928c5fe1382fb20dc850" ALTER COLUMN "CD_sourceIds" SET DEFAULT '[]';
ALTER TABLE ONLY ties_data."c6f3a3396e9165e886da928c5fe1382fb20dc850" ALTER COLUMN "CD_classifiers" SET DEFAULT '[]';
ALTER TABLE ONLY ties_data."c6f3a3396e9165e886da928c5fe1382fb20dc850" ALTER COLUMN "CD_decorators" SET DEFAULT '{}';

CREATE TABLE IF NOT EXISTS ties_data."e01fcb87ad2c34ce66c34420255e25aaca270e5e" (
	"id"			VARCHAR(511),
	"name"			TEXT,
	"CD_sourceIds"			jsonb,
	"CD_classifiers"			jsonb,
	"CD_decorators"			jsonb,
	"REL_FK_realised-managedElement"			VARCHAR(511),
	"REL_ID_MANAGEDELEMENT_REALISED_BY_CLOUDNATIVEAPPLICATION"			VARCHAR(511),
	"REL_CD_8F561B5FB3CF928F2C4046CE1A7C37A8FE06B9A7"			jsonb,
	"REL_CD_CCEBD4C63B90BD1764CB5A15C282D6CDBDF0B1F2"			jsonb,
	"REL_CD_21E2495C31F0DBF735976C90F4CD10D1215190E1"			jsonb,
	"REL_FK_comprised-by-cloudNativeSystem"			VARCHAR(511),
	"REL_ID_CLOUDNATIVESYSTEM_COMPRISES_CLOUDNATIVEAPPLICATION"			VARCHAR(511),
	"REL_CD_39262797D0119611B8459ECF46754A074711E485"			jsonb,
	"REL_CD_026A1F92A7D93728916AF3DCC2C013FB79E29D07"			jsonb,
	"REL_CD_D32E90288E1982363B2BD8DA9D2E90AA16F71575"			jsonb,
	"REL_FK_deployed-on-namespace"			VARCHAR(511),
	"REL_ID_CLOUDNATIVEAPPLICATION_DEPLOYED_ON_NAMESPACE"			VARCHAR(511),
	"REL_CD_sourceIds_CLOUDNATIVEAPPLICATION_DEPLOYED_ON_NAMESPACE"			jsonb,
	"REL_CD_classifiers_CLOUDNATIVEAPPLICATION_DEPLOYED_ON_NAMESPACE"			jsonb,
	"REL_CD_decorators_CLOUDNATIVEAPPLICATION_DEPLOYED_ON_NAMESPACE"			jsonb
);

ALTER TABLE ONLY ties_data."e01fcb87ad2c34ce66c34420255e25aaca270e5e" ALTER COLUMN "CD_sourceIds" SET DEFAULT '[]';
ALTER TABLE ONLY ties_data."e01fcb87ad2c34ce66c34420255e25aaca270e5e" ALTER COLUMN "CD_classifiers" SET DEFAULT '[]';
ALTER TABLE ONLY ties_data."e01fcb87ad2c34ce66c34420255e25aaca270e5e" ALTER COLUMN "CD_decorators" SET DEFAULT '{}';

ALTER TABLE ONLY ties_data."e01fcb87ad2c34ce66c34420255e25aaca270e5e" ALTER COLUMN "REL_CD_8F561B5FB3CF928F2C4046CE1A7C37A8FE06B9A7" SET DEFAULT '[]';
ALTER TABLE ONLY ties_data."e01fcb87ad2c34ce66c34420255e25aaca270e5e" ALTER COLUMN "REL_CD_CCEBD4C63B90BD1764CB5A15C282D6CDBDF0B1F2" SET DEFAULT '[]';
ALTER TABLE ONLY ties_data."e01fcb87ad2c34ce66c34420255e25aaca270e5e" ALTER COLUMN "REL_CD_21E2495C31F0DBF735976C90F4CD10D1215190E1" SET DEFAULT '{}';

ALTER TABLE ONLY ties_data."e01fcb87ad2c34ce66c34420255e25aaca270e5e" ALTER COLUMN "REL_CD_39262797D0119611B8459ECF46754A074711E485" SET DEFAULT '[]';
ALTER TABLE ONLY ties_data."e01fcb87ad2c34ce66c34420255e25aaca270e5e" ALTER COLUMN "REL_CD_026A1F92A7D93728916AF3DCC2C013FB79E29D07" SET DEFAULT '[]';
ALTER TABLE ONLY ties_data."e01fcb87ad2c34ce66c34420255e25aaca270e5e" ALTER COLUMN "REL_CD_D32E90288E1982363B2BD8DA9D2E90AA16F71575" SET DEFAULT '{}';

ALTER TABLE ONLY ties_data."e01fcb87ad2c34ce66c34420255e25aaca270e5e" ALTER COLUMN "REL_CD_sourceIds_CLOUDNATIVEAPPLICATION_DEPLOYED_ON_NAMESPACE" SET DEFAULT '[]';
ALTER TABLE ONLY ties_data."e01fcb87ad2c34ce66c34420255e25aaca270e5e" ALTER COLUMN "REL_CD_classifiers_CLOUDNATIVEAPPLICATION_DEPLOYED_ON_NAMESPACE" SET DEFAULT '[]';
ALTER TABLE ONLY ties_data."e01fcb87ad2c34ce66c34420255e25aaca270e5e" ALTER COLUMN "REL_CD_decorators_CLOUDNATIVEAPPLICATION_DEPLOYED_ON_NAMESPACE" SET DEFAULT '{}';

CREATE TABLE IF NOT EXISTS ties_data."163276fa439cdfccabb80f7acacb6fa638e8d314" (
	"id"			VARCHAR(511),
	"CD_sourceIds" jsonb,
	"CD_classifiers"			jsonb,
	"CD_decorators"			jsonb,
	"name"			TEXT,
	"REL_FK_deployed-managedElement"			VARCHAR(511)
);

ALTER TABLE ONLY ties_data."163276fa439cdfccabb80f7acacb6fa638e8d314" ALTER COLUMN "CD_sourceIds" SET DEFAULT '[]';
ALTER TABLE ONLY ties_data."163276fa439cdfccabb80f7acacb6fa638e8d314" ALTER COLUMN "CD_classifiers" SET DEFAULT '[]';
ALTER TABLE ONLY ties_data."163276fa439cdfccabb80f7acacb6fa638e8d314" ALTER COLUMN "CD_decorators" SET DEFAULT '{}';

CREATE TABLE IF NOT EXISTS ties_data."o-ran-smo-teiv-ran-cloud_CloudSite" (
	"id"			VARCHAR(511),
	"CD_sourceIds" jsonb,
	"CD_classifiers"			jsonb,
	"CD_decorators"			jsonb,
	"name"			TEXT,
	"geo-location"			geography
);

ALTER TABLE ONLY ties_data."o-ran-smo-teiv-ran-cloud_CloudSite" ALTER COLUMN "CD_sourceIds" SET DEFAULT '[]';
ALTER TABLE ONLY ties_data."o-ran-smo-teiv-ran-cloud_CloudSite" ALTER COLUMN "CD_classifiers" SET DEFAULT '[]';
ALTER TABLE ONLY ties_data."o-ran-smo-teiv-ran-cloud_CloudSite" ALTER COLUMN "CD_decorators" SET DEFAULT '{}';

CREATE TABLE IF NOT EXISTS ties_data."o-ran-smo-teiv-ran-logical_ENodeBFunction" (
	"id"			VARCHAR(511),
	"fdn"			TEXT,
	"eNBId"			BIGINT,
	"cmId"			jsonb,
	"eNodeBPlmnId"			jsonb,
	"CD_sourceIds"			jsonb,
	"CD_classifiers"			jsonb,
	"CD_decorators"			jsonb,
	"REL_FK_managed-by-managedElement"			VARCHAR(511),
	"REL_ID_MANAGEDELEMENT_MANAGES_ENODEBFUNCTION"			VARCHAR(511),
	"REL_CD_sourceIds_MANAGEDELEMENT_MANAGES_ENODEBFUNCTION"			jsonb,
	"REL_CD_classifiers_MANAGEDELEMENT_MANAGES_ENODEBFUNCTION"			jsonb,
	"REL_CD_decorators_MANAGEDELEMENT_MANAGES_ENODEBFUNCTION"			jsonb,
	"REL_FK_realised-by-physicalNetworkAppliance"			VARCHAR(511),
	"REL_ID_ENODEBFUNCTION_REALISED_BY_PHYSICALNETWORKAPPLIANCE"			VARCHAR(511),
	"REL_CD_556274C475BA56EE4DEFB691F9037C869223A124"			jsonb,
	"REL_CD_C6C6D295144A637110DA4E6121BE13F30EFDBEBF"			jsonb,
	"REL_CD_B369805A0EB24F7C841B0E541A015F85AE2A23B1"			jsonb
);

ALTER TABLE ONLY ties_data."o-ran-smo-teiv-ran-logical_ENodeBFunction" ALTER COLUMN "CD_sourceIds" SET DEFAULT '[]';
ALTER TABLE ONLY ties_data."o-ran-smo-teiv-ran-logical_ENodeBFunction" ALTER COLUMN "CD_classifiers" SET DEFAULT '[]';
ALTER TABLE ONLY ties_data."o-ran-smo-teiv-ran-logical_ENodeBFunction" ALTER COLUMN "CD_decorators" SET DEFAULT '{}';

ALTER TABLE ONLY ties_data."o-ran-smo-teiv-ran-logical_ENodeBFunction" ALTER COLUMN "REL_CD_sourceIds_MANAGEDELEMENT_MANAGES_ENODEBFUNCTION" SET DEFAULT '[]';
ALTER TABLE ONLY ties_data."o-ran-smo-teiv-ran-logical_ENodeBFunction" ALTER COLUMN "REL_CD_classifiers_MANAGEDELEMENT_MANAGES_ENODEBFUNCTION" SET DEFAULT '[]';
ALTER TABLE ONLY ties_data."o-ran-smo-teiv-ran-logical_ENodeBFunction" ALTER COLUMN "REL_CD_decorators_MANAGEDELEMENT_MANAGES_ENODEBFUNCTION" SET DEFAULT '{}';

ALTER TABLE ONLY ties_data."o-ran-smo-teiv-ran-logical_ENodeBFunction" ALTER COLUMN "REL_CD_556274C475BA56EE4DEFB691F9037C869223A124" SET DEFAULT '[]';
ALTER TABLE ONLY ties_data."o-ran-smo-teiv-ran-logical_ENodeBFunction" ALTER COLUMN "REL_CD_C6C6D295144A637110DA4E6121BE13F30EFDBEBF" SET DEFAULT '[]';
ALTER TABLE ONLY ties_data."o-ran-smo-teiv-ran-logical_ENodeBFunction" ALTER COLUMN "REL_CD_B369805A0EB24F7C841B0E541A015F85AE2A23B1" SET DEFAULT '{}';

CREATE TABLE IF NOT EXISTS ties_data."o-ran-smo-teiv-ran-logical_EUtranCell" (
	"id"			VARCHAR(511),
	"CD_sourceIds"     jsonb,
	"CD_classifiers"			jsonb,
	"CD_decorators"			jsonb,
	"earfcn"			BIGINT,
	"earfcndl"			BIGINT,
	"duplexType"			TEXT,
	"fdn"			TEXT,
	"tac"			BIGINT,
	"earfcnul"			BIGINT,
	"cmId"			jsonb,
	"cellId"			BIGINT,
	"REL_FK_grouped-by-sector"			VARCHAR(511),
	"REL_ID_SECTOR_GROUPS_EUTRANCELL"			VARCHAR(511),
	"REL_CD_sourceIds_SECTOR_GROUPS_EUTRANCELL"			jsonb,
	"REL_CD_classifiers_SECTOR_GROUPS_EUTRANCELL"			jsonb,
	"REL_CD_decorators_SECTOR_GROUPS_EUTRANCELL"			jsonb,
	"REL_FK_provided-by-enodebFunction"			VARCHAR(511),
	"REL_ID_ENODEBFUNCTION_PROVIDES_EUTRANCELL"			VARCHAR(511),
	"REL_CD_sourceIds_ENODEBFUNCTION_PROVIDES_EUTRANCELL"			jsonb,
	"REL_CD_classifiers_ENODEBFUNCTION_PROVIDES_EUTRANCELL"			jsonb,
	"REL_CD_decorators_ENODEBFUNCTION_PROVIDES_EUTRANCELL"			jsonb
);

ALTER TABLE ONLY ties_data."o-ran-smo-teiv-ran-logical_EUtranCell" ALTER COLUMN "CD_sourceIds" SET DEFAULT '[]';
ALTER TABLE ONLY ties_data."o-ran-smo-teiv-ran-logical_EUtranCell" ALTER COLUMN "CD_classifiers" SET DEFAULT '[]';
ALTER TABLE ONLY ties_data."o-ran-smo-teiv-ran-logical_EUtranCell" ALTER COLUMN "CD_decorators" SET DEFAULT '{}';

ALTER TABLE ONLY ties_data."o-ran-smo-teiv-ran-logical_EUtranCell" ALTER COLUMN "REL_CD_sourceIds_SECTOR_GROUPS_EUTRANCELL" SET DEFAULT '[]';
ALTER TABLE ONLY ties_data."o-ran-smo-teiv-ran-logical_EUtranCell" ALTER COLUMN "REL_CD_classifiers_SECTOR_GROUPS_EUTRANCELL" SET DEFAULT '[]';
ALTER TABLE ONLY ties_data."o-ran-smo-teiv-ran-logical_EUtranCell" ALTER COLUMN "REL_CD_decorators_SECTOR_GROUPS_EUTRANCELL" SET DEFAULT '{}';

ALTER TABLE ONLY ties_data."o-ran-smo-teiv-ran-logical_EUtranCell" ALTER COLUMN "REL_CD_sourceIds_ENODEBFUNCTION_PROVIDES_EUTRANCELL" SET DEFAULT '[]';
ALTER TABLE ONLY ties_data."o-ran-smo-teiv-ran-logical_EUtranCell" ALTER COLUMN "REL_CD_classifiers_ENODEBFUNCTION_PROVIDES_EUTRANCELL" SET DEFAULT '[]';
ALTER TABLE ONLY ties_data."o-ran-smo-teiv-ran-logical_EUtranCell" ALTER COLUMN "REL_CD_decorators_ENODEBFUNCTION_PROVIDES_EUTRANCELL" SET DEFAULT '{}';


CREATE TABLE IF NOT EXISTS ties_data."7cd7062ea24531b2f48e4f2fdc51eaf0b82f88c7" (
	"id"			VARCHAR(511),
	"aSide_GNBCUCPFunction"			VARCHAR(511),
	"bSide_CloudNativeApplication"			VARCHAR(511),
	"CD_sourceIds"         jsonb,
	"CD_classifiers"			jsonb,
	"CD_decorators"			jsonb
);

ALTER TABLE ONLY ties_data."7cd7062ea24531b2f48e4f2fdc51eaf0b82f88c7" ALTER COLUMN "CD_sourceIds" SET DEFAULT '[]';
ALTER TABLE ONLY ties_data."7cd7062ea24531b2f48e4f2fdc51eaf0b82f88c7" ALTER COLUMN "CD_classifiers" SET DEFAULT '[]';
ALTER TABLE ONLY ties_data."7cd7062ea24531b2f48e4f2fdc51eaf0b82f88c7" ALTER COLUMN "CD_decorators" SET DEFAULT '{}';

CREATE TABLE IF NOT EXISTS ties_data."c4a425179d3089b5288fdf059079d0ea26977f0f" (
	"id"			VARCHAR(511),
	"CD_sourceIds"     jsonb,
	"CD_classifiers"			jsonb,
	"CD_decorators"			jsonb,
	"fdn"			TEXT,
	"pLMNId"			jsonb,
	"gNBCUName"			TEXT,
	"gNBId"			BIGINT,
	"cmId"			jsonb,
	"gNBIdLength"			INTEGER,
	"REL_FK_managed-by-managedElement"			VARCHAR(511),
	"REL_ID_MANAGEDELEMENT_MANAGES_GNBCUCPFUNCTION"			VARCHAR(511),
	"REL_CD_sourceIds_MANAGEDELEMENT_MANAGES_GNBCUCPFUNCTION"			jsonb,
	"REL_CD_classifiers_MANAGEDELEMENT_MANAGES_GNBCUCPFUNCTION"			jsonb,
	"REL_CD_decorators_MANAGEDELEMENT_MANAGES_GNBCUCPFUNCTION"			jsonb
);

ALTER TABLE ONLY ties_data."c4a425179d3089b5288fdf059079d0ea26977f0f" ALTER COLUMN "CD_sourceIds" SET DEFAULT '[]';
ALTER TABLE ONLY ties_data."c4a425179d3089b5288fdf059079d0ea26977f0f" ALTER COLUMN "CD_classifiers" SET DEFAULT '[]';
ALTER TABLE ONLY ties_data."c4a425179d3089b5288fdf059079d0ea26977f0f" ALTER COLUMN "CD_decorators" SET DEFAULT '{}';

ALTER TABLE ONLY ties_data."c4a425179d3089b5288fdf059079d0ea26977f0f" ALTER COLUMN "REL_CD_sourceIds_MANAGEDELEMENT_MANAGES_GNBCUCPFUNCTION" SET DEFAULT '[]';
ALTER TABLE ONLY ties_data."c4a425179d3089b5288fdf059079d0ea26977f0f" ALTER COLUMN "REL_CD_classifiers_MANAGEDELEMENT_MANAGES_GNBCUCPFUNCTION" SET DEFAULT '[]';
ALTER TABLE ONLY ties_data."c4a425179d3089b5288fdf059079d0ea26977f0f" ALTER COLUMN "REL_CD_decorators_MANAGEDELEMENT_MANAGES_GNBCUCPFUNCTION" SET DEFAULT '{}';


CREATE TABLE IF NOT EXISTS ties_data."70a4a84bca01ea022ab24d8cb82422c572922675" (
	"id"			VARCHAR(511),
	"aSide_GNBCUUPFunction"			VARCHAR(511),
	"bSide_CloudNativeApplication"			VARCHAR(511),
	"CD_sourceIds"     jsonb,
	"CD_classifiers"			jsonb,
	"CD_decorators"			jsonb
);

ALTER TABLE ONLY ties_data."70a4a84bca01ea022ab24d8cb82422c572922675" ALTER COLUMN "CD_sourceIds" SET DEFAULT '[]';
ALTER TABLE ONLY ties_data."70a4a84bca01ea022ab24d8cb82422c572922675" ALTER COLUMN "CD_classifiers" SET DEFAULT '[]';
ALTER TABLE ONLY ties_data."70a4a84bca01ea022ab24d8cb82422c572922675" ALTER COLUMN "CD_decorators" SET DEFAULT '{}';

CREATE TABLE IF NOT EXISTS ties_data."8fe520ccd54b8f72ef7b2d3061264ddc2481e4eb" (
	"id"			VARCHAR(511),
	"CD_sourceIds"     jsonb,
	"CD_classifiers"			jsonb,
	"CD_decorators"			jsonb,
	"gNBId"			BIGINT,
	"fdn"			TEXT,
	"cmId"			jsonb,
	"gNBIdLength"			INTEGER,
	"REL_FK_managed-by-managedElement"			VARCHAR(511),
	"REL_ID_MANAGEDELEMENT_MANAGES_GNBCUUPFUNCTION"			VARCHAR(511),
	"REL_CD_sourceIds_MANAGEDELEMENT_MANAGES_GNBCUUPFUNCTION"			jsonb,
	"REL_CD_classifiers_MANAGEDELEMENT_MANAGES_GNBCUUPFUNCTION"			jsonb,
	"REL_CD_decorators_MANAGEDELEMENT_MANAGES_GNBCUUPFUNCTION"			jsonb
);

ALTER TABLE ONLY ties_data."8fe520ccd54b8f72ef7b2d3061264ddc2481e4eb" ALTER COLUMN "CD_sourceIds" SET DEFAULT '[]';
ALTER TABLE ONLY ties_data."8fe520ccd54b8f72ef7b2d3061264ddc2481e4eb" ALTER COLUMN "CD_classifiers" SET DEFAULT '[]';
ALTER TABLE ONLY ties_data."8fe520ccd54b8f72ef7b2d3061264ddc2481e4eb" ALTER COLUMN "CD_decorators" SET DEFAULT '{}';

ALTER TABLE ONLY ties_data."8fe520ccd54b8f72ef7b2d3061264ddc2481e4eb" ALTER COLUMN "REL_CD_sourceIds_MANAGEDELEMENT_MANAGES_GNBCUUPFUNCTION" SET DEFAULT '[]';
ALTER TABLE ONLY ties_data."8fe520ccd54b8f72ef7b2d3061264ddc2481e4eb" ALTER COLUMN "REL_CD_classifiers_MANAGEDELEMENT_MANAGES_GNBCUUPFUNCTION" SET DEFAULT '[]';
ALTER TABLE ONLY ties_data."8fe520ccd54b8f72ef7b2d3061264ddc2481e4eb" ALTER COLUMN "REL_CD_decorators_MANAGEDELEMENT_MANAGES_GNBCUUPFUNCTION" SET DEFAULT '{}';


CREATE TABLE IF NOT EXISTS ties_data."10484f157f490eb5b27e40dbfaf4d5f2be17c57c" (
	"id"			VARCHAR(511),
	"aSide_GNBDUFunction"			VARCHAR(511),
	"bSide_CloudNativeApplication"			VARCHAR(511),
	"CD_sourceIds"     jsonb,
	"CD_classifiers"			jsonb,
	"CD_decorators"			jsonb
);

ALTER TABLE ONLY ties_data."10484f157f490eb5b27e40dbfaf4d5f2be17c57c" ALTER COLUMN "CD_sourceIds" SET DEFAULT '[]';
ALTER TABLE ONLY ties_data."10484f157f490eb5b27e40dbfaf4d5f2be17c57c" ALTER COLUMN "CD_classifiers" SET DEFAULT '[]';
ALTER TABLE ONLY ties_data."10484f157f490eb5b27e40dbfaf4d5f2be17c57c" ALTER COLUMN "CD_decorators" SET DEFAULT '{}';

CREATE TABLE IF NOT EXISTS ties_data."o-ran-smo-teiv-ran-logical_GNBDUFunction" (
	"id"			VARCHAR(511),
	"CD_sourceIds" jsonb,
	"CD_classifiers"			jsonb,
	"CD_decorators"			jsonb,
	"fdn"			TEXT,
	"gNBId"			BIGINT,
	"dUpLMNId"			jsonb,
	"gNBDUId"			BIGINT,
	"cmId"			jsonb,
	"gNBIdLength"			INTEGER,
	"REL_FK_managed-by-managedElement"			VARCHAR(511),
	"REL_ID_MANAGEDELEMENT_MANAGES_GNBDUFUNCTION"			VARCHAR(511),
	"REL_CD_sourceIds_MANAGEDELEMENT_MANAGES_GNBDUFUNCTION"       jsonb,
	"REL_CD_classifiers_MANAGEDELEMENT_MANAGES_GNBDUFUNCTION"       jsonb,
	"REL_CD_decorators_MANAGEDELEMENT_MANAGES_GNBDUFUNCTION"       jsonb
);

ALTER TABLE ONLY ties_data."o-ran-smo-teiv-ran-logical_GNBDUFunction" ALTER COLUMN "CD_sourceIds" SET DEFAULT '[]';
ALTER TABLE ONLY ties_data."o-ran-smo-teiv-ran-logical_GNBDUFunction" ALTER COLUMN "CD_classifiers" SET DEFAULT '[]';
ALTER TABLE ONLY ties_data."o-ran-smo-teiv-ran-logical_GNBDUFunction" ALTER COLUMN "CD_decorators" SET DEFAULT '{}';

ALTER TABLE ONLY ties_data."o-ran-smo-teiv-ran-logical_GNBDUFunction" ALTER COLUMN "REL_CD_sourceIds_MANAGEDELEMENT_MANAGES_GNBDUFUNCTION" SET DEFAULT '[]';
ALTER TABLE ONLY ties_data."o-ran-smo-teiv-ran-logical_GNBDUFunction" ALTER COLUMN "REL_CD_classifiers_MANAGEDELEMENT_MANAGES_GNBDUFUNCTION" SET DEFAULT '[]';
ALTER TABLE ONLY ties_data."o-ran-smo-teiv-ran-logical_GNBDUFunction" ALTER COLUMN "REL_CD_decorators_MANAGEDELEMENT_MANAGES_GNBDUFUNCTION" SET DEFAULT '{}';


CREATE TABLE IF NOT EXISTS ties_data."c88307168935f02fdecc084ea5040bb9db16c701" (
	"id"			VARCHAR(511),
	"CD_sourceIds"     jsonb,
	"CD_classifiers"			jsonb,
	"CD_decorators"			jsonb,
	"sectorCarrierType"			TEXT,
	"essScLocalId"			BIGINT,
	"fdn"			TEXT,
	"cmId"			jsonb,
	"REL_FK_provided-by-enodebFunction"			VARCHAR(511),
	"REL_ID_ENODEBFUNCTION_PROVIDES_LTESECTORCARRIER"			VARCHAR(511),
	"REL_CD_sourceIds_ENODEBFUNCTION_PROVIDES_LTESECTORCARRIER"			jsonb,
	"REL_CD_classifiers_ENODEBFUNCTION_PROVIDES_LTESECTORCARRIER"			jsonb,
	"REL_CD_decorators_ENODEBFUNCTION_PROVIDES_LTESECTORCARRIER"			jsonb,
	"REL_FK_used-antennaCapability"			VARCHAR(511),
	"REL_ID_LTESECTORCARRIER_USES_ANTENNACAPABILITY"			VARCHAR(511),
	"REL_CD_sourceIds_LTESECTORCARRIER_USES_ANTENNACAPABILITY"			jsonb,
	"REL_CD_classifiers_LTESECTORCARRIER_USES_ANTENNACAPABILITY"			jsonb,
	"REL_CD_decorators_LTESECTORCARRIER_USES_ANTENNACAPABILITY"			jsonb,
	"REL_FK_used-by-euTranCell"			VARCHAR(511),
	"REL_ID_EUTRANCELL_USES_LTESECTORCARRIER"			VARCHAR(511),
	"REL_CD_sourceIds_EUTRANCELL_USES_LTESECTORCARRIER"			jsonb,
	"REL_CD_classifiers_EUTRANCELL_USES_LTESECTORCARRIER"			jsonb,
	"REL_CD_decorators_EUTRANCELL_USES_LTESECTORCARRIER"			jsonb
);

ALTER TABLE ONLY ties_data."c88307168935f02fdecc084ea5040bb9db16c701" ALTER COLUMN "CD_sourceIds" SET DEFAULT '[]';
ALTER TABLE ONLY ties_data."c88307168935f02fdecc084ea5040bb9db16c701" ALTER COLUMN "CD_classifiers" SET DEFAULT '[]';
ALTER TABLE ONLY ties_data."c88307168935f02fdecc084ea5040bb9db16c701" ALTER COLUMN "CD_decorators" SET DEFAULT '{}';

ALTER TABLE ONLY ties_data."c88307168935f02fdecc084ea5040bb9db16c701" ALTER COLUMN "REL_CD_sourceIds_ENODEBFUNCTION_PROVIDES_LTESECTORCARRIER" SET DEFAULT '[]';
ALTER TABLE ONLY ties_data."c88307168935f02fdecc084ea5040bb9db16c701" ALTER COLUMN "REL_CD_classifiers_ENODEBFUNCTION_PROVIDES_LTESECTORCARRIER" SET DEFAULT '[]';
ALTER TABLE ONLY ties_data."c88307168935f02fdecc084ea5040bb9db16c701" ALTER COLUMN "REL_CD_decorators_ENODEBFUNCTION_PROVIDES_LTESECTORCARRIER" SET DEFAULT '{}';

ALTER TABLE ONLY ties_data."c88307168935f02fdecc084ea5040bb9db16c701" ALTER COLUMN "REL_CD_sourceIds_LTESECTORCARRIER_USES_ANTENNACAPABILITY" SET DEFAULT '[]';
ALTER TABLE ONLY ties_data."c88307168935f02fdecc084ea5040bb9db16c701" ALTER COLUMN "REL_CD_classifiers_LTESECTORCARRIER_USES_ANTENNACAPABILITY" SET DEFAULT '[]';
ALTER TABLE ONLY ties_data."c88307168935f02fdecc084ea5040bb9db16c701" ALTER COLUMN "REL_CD_decorators_LTESECTORCARRIER_USES_ANTENNACAPABILITY" SET DEFAULT '{}';

ALTER TABLE ONLY ties_data."c88307168935f02fdecc084ea5040bb9db16c701" ALTER COLUMN "REL_CD_sourceIds_EUTRANCELL_USES_LTESECTORCARRIER" SET DEFAULT '[]';
ALTER TABLE ONLY ties_data."c88307168935f02fdecc084ea5040bb9db16c701" ALTER COLUMN "REL_CD_classifiers_EUTRANCELL_USES_LTESECTORCARRIER" SET DEFAULT '[]';
ALTER TABLE ONLY ties_data."c88307168935f02fdecc084ea5040bb9db16c701" ALTER COLUMN "REL_CD_decorators_EUTRANCELL_USES_LTESECTORCARRIER" SET DEFAULT '{}';

CREATE TABLE IF NOT EXISTS ties_data."o-ran-smo-teiv-ran-oam_ManagedElement" (
	"id"			VARCHAR(511),
	"CD_sourceIds"     jsonb,
	"CD_classifiers"			jsonb,
	"CD_decorators"			jsonb,
	"fdn"			TEXT,
	"cmId"			jsonb,
	"REL_FK_deployed-as-cloudNativeSystem"			VARCHAR(511),
	"REL_ID_MANAGEDELEMENT_DEPLOYED_AS_CLOUDNATIVESYSTEM"			VARCHAR(511),
	"REL_CD_sourceIds_MANAGEDELEMENT_DEPLOYED_AS_CLOUDNATIVESYSTEM"			jsonb,
	"REL_CD_classifiers_MANAGEDELEMENT_DEPLOYED_AS_CLOUDNATIVESYSTEM"			jsonb,
	"REL_CD_decorators_MANAGEDELEMENT_DEPLOYED_AS_CLOUDNATIVESYSTEM"			jsonb
);

ALTER TABLE ONLY ties_data."o-ran-smo-teiv-ran-oam_ManagedElement" ALTER COLUMN "CD_sourceIds" SET DEFAULT '[]';
ALTER TABLE ONLY ties_data."o-ran-smo-teiv-ran-oam_ManagedElement" ALTER COLUMN "CD_classifiers" SET DEFAULT '[]';
ALTER TABLE ONLY ties_data."o-ran-smo-teiv-ran-oam_ManagedElement" ALTER COLUMN "CD_decorators" SET DEFAULT '{}';

ALTER TABLE ONLY ties_data."o-ran-smo-teiv-ran-oam_ManagedElement" ALTER COLUMN "REL_CD_sourceIds_MANAGEDELEMENT_DEPLOYED_AS_CLOUDNATIVESYSTEM" SET DEFAULT '[]';
ALTER TABLE ONLY ties_data."o-ran-smo-teiv-ran-oam_ManagedElement" ALTER COLUMN "REL_CD_classifiers_MANAGEDELEMENT_DEPLOYED_AS_CLOUDNATIVESYSTEM" SET DEFAULT '[]';
ALTER TABLE ONLY ties_data."o-ran-smo-teiv-ran-oam_ManagedElement" ALTER COLUMN "REL_CD_decorators_MANAGEDELEMENT_DEPLOYED_AS_CLOUDNATIVESYSTEM" SET DEFAULT '{}';

CREATE TABLE IF NOT EXISTS ties_data."o-ran-smo-teiv-ran-logical_NRCellCU" (
	"id"			VARCHAR(511),
	"CD_sourceIds"			jsonb,
	"CD_classifiers"			jsonb,
	"CD_decorators"			jsonb,
	"nCI"			BIGINT,
	"plmnId"			jsonb,
	"fdn"			TEXT,
	"nRTAC"			BIGINT,
	"cellLocalId"			BIGINT,
	"cmId"			jsonb,
	"REL_FK_provided-by-gnbcucpFunction"			VARCHAR(511),
	"REL_ID_GNBCUCPFUNCTION_PROVIDES_NRCELLCU"			VARCHAR(511),
	"REL_CD_sourceIds_GNBCUCPFUNCTION_PROVIDES_NRCELLCU"			jsonb,
	"REL_CD_classifiers_GNBCUCPFUNCTION_PROVIDES_NRCELLCU"			jsonb,
	"REL_CD_decorators_GNBCUCPFUNCTION_PROVIDES_NRCELLCU"			jsonb
);

ALTER TABLE ONLY ties_data."o-ran-smo-teiv-ran-logical_NRCellCU" ALTER COLUMN "CD_sourceIds" SET DEFAULT '[]';
ALTER TABLE ONLY ties_data."o-ran-smo-teiv-ran-logical_NRCellCU" ALTER COLUMN "CD_classifiers" SET DEFAULT '[]';
ALTER TABLE ONLY ties_data."o-ran-smo-teiv-ran-logical_NRCellCU" ALTER COLUMN "CD_decorators" SET DEFAULT '{}';

ALTER TABLE ONLY ties_data."o-ran-smo-teiv-ran-logical_NRCellCU" ALTER COLUMN "REL_CD_sourceIds_GNBCUCPFUNCTION_PROVIDES_NRCELLCU" SET DEFAULT '[]';
ALTER TABLE ONLY ties_data."o-ran-smo-teiv-ran-logical_NRCellCU" ALTER COLUMN "REL_CD_classifiers_GNBCUCPFUNCTION_PROVIDES_NRCELLCU" SET DEFAULT '[]';
ALTER TABLE ONLY ties_data."o-ran-smo-teiv-ran-logical_NRCellCU" ALTER COLUMN "REL_CD_decorators_GNBCUCPFUNCTION_PROVIDES_NRCELLCU" SET DEFAULT '{}';


CREATE TABLE IF NOT EXISTS ties_data."o-ran-smo-teiv-ran-logical_NRCellDU" (
	"id"			VARCHAR(511),
	"CD_sourceIds"			jsonb,
	"CD_classifiers"			jsonb,
	"CD_decorators"			jsonb,
	"nRTAC"			BIGINT,
	"fdn"			TEXT,
	"nRPCI"			BIGINT,
	"nCI"			BIGINT,
	"cellLocalId"			BIGINT,
	"cmId"			jsonb,
	"REL_FK_grouped-by-sector"			VARCHAR(511),
	"REL_ID_SECTOR_GROUPS_NRCELLDU"			VARCHAR(511),
	"REL_CD_sourceIds_SECTOR_GROUPS_NRCELLDU"			jsonb,
	"REL_CD_classifiers_SECTOR_GROUPS_NRCELLDU"			jsonb,
	"REL_CD_decorators_SECTOR_GROUPS_NRCELLDU"			jsonb,
	"REL_FK_provided-by-gnbduFunction"			VARCHAR(511),
	"REL_ID_GNBDUFUNCTION_PROVIDES_NRCELLDU"			VARCHAR(511),
	"REL_CD_sourceIds_GNBDUFUNCTION_PROVIDES_NRCELLDU"			jsonb,
	"REL_CD_classifiers_GNBDUFUNCTION_PROVIDES_NRCELLDU"			jsonb,
	"REL_CD_decorators_GNBDUFUNCTION_PROVIDES_NRCELLDU"			jsonb
);

ALTER TABLE ONLY ties_data."o-ran-smo-teiv-ran-logical_NRCellDU" ALTER COLUMN "CD_sourceIds" SET DEFAULT '[]';
ALTER TABLE ONLY ties_data."o-ran-smo-teiv-ran-logical_NRCellDU" ALTER COLUMN "CD_classifiers" SET DEFAULT '[]';
ALTER TABLE ONLY ties_data."o-ran-smo-teiv-ran-logical_NRCellDU" ALTER COLUMN "CD_decorators" SET DEFAULT '{}';

ALTER TABLE ONLY ties_data."o-ran-smo-teiv-ran-logical_NRCellDU" ALTER COLUMN "REL_CD_sourceIds_SECTOR_GROUPS_NRCELLDU" SET DEFAULT '[]';
ALTER TABLE ONLY ties_data."o-ran-smo-teiv-ran-logical_NRCellDU" ALTER COLUMN "REL_CD_classifiers_SECTOR_GROUPS_NRCELLDU" SET DEFAULT '[]';
ALTER TABLE ONLY ties_data."o-ran-smo-teiv-ran-logical_NRCellDU" ALTER COLUMN "REL_CD_decorators_SECTOR_GROUPS_NRCELLDU" SET DEFAULT '{}';

ALTER TABLE ONLY ties_data."o-ran-smo-teiv-ran-logical_NRCellDU" ALTER COLUMN "REL_CD_sourceIds_GNBDUFUNCTION_PROVIDES_NRCELLDU" SET DEFAULT '[]';
ALTER TABLE ONLY ties_data."o-ran-smo-teiv-ran-logical_NRCellDU" ALTER COLUMN "REL_CD_classifiers_GNBDUFUNCTION_PROVIDES_NRCELLDU" SET DEFAULT '[]';
ALTER TABLE ONLY ties_data."o-ran-smo-teiv-ran-logical_NRCellDU" ALTER COLUMN "REL_CD_decorators_GNBDUFUNCTION_PROVIDES_NRCELLDU" SET DEFAULT '{}';

CREATE TABLE IF NOT EXISTS ties_data."39a335dca201ef99ae06f4ffd1908b534f8c6c39" (
	"id"			VARCHAR(511),
	"CD_sourceIds"			jsonb,
	"CD_classifiers"			jsonb,
	"CD_decorators"			jsonb,
	"frequencyDL"			BIGINT,
	"arfcnDL"			BIGINT,
	"fdn"			TEXT,
	"essScLocalId"			BIGINT,
	"frequencyUL"			BIGINT,
	"cmId"			jsonb,
	"arfcnUL"			BIGINT,
	"REL_FK_used-by-nrCellDu"			VARCHAR(511),
	"REL_ID_NRCELLDU_USES_NRSECTORCARRIER"			VARCHAR(511),
	"REL_CD_sourceIds_NRCELLDU_USES_NRSECTORCARRIER"			jsonb,
	"REL_CD_classifiers_NRCELLDU_USES_NRSECTORCARRIER"			jsonb,
	"REL_CD_decorators_NRCELLDU_USES_NRSECTORCARRIER"			jsonb,
	"REL_FK_provided-by-gnbduFunction"			VARCHAR(511),
	"REL_ID_GNBDUFUNCTION_PROVIDES_NRSECTORCARRIER"			VARCHAR(511),
	"REL_CD_sourceIds_GNBDUFUNCTION_PROVIDES_NRSECTORCARRIER"			jsonb,
	"REL_CD_classifiers_GNBDUFUNCTION_PROVIDES_NRSECTORCARRIER"			jsonb,
	"REL_CD_decorators_GNBDUFUNCTION_PROVIDES_NRSECTORCARRIER"			jsonb,
	"REL_FK_used-antennaCapability"			VARCHAR(511),
	"REL_ID_NRSECTORCARRIER_USES_ANTENNACAPABILITY"			VARCHAR(511),
	"REL_CD_sourceIds_NRSECTORCARRIER_USES_ANTENNACAPABILITY"			jsonb,
	"REL_CD_classifiers_NRSECTORCARRIER_USES_ANTENNACAPABILITY"			jsonb,
	"REL_CD_decorators_NRSECTORCARRIER_USES_ANTENNACAPABILITY"			jsonb
);

ALTER TABLE ONLY ties_data."39a335dca201ef99ae06f4ffd1908b534f8c6c39" ALTER COLUMN "CD_sourceIds" SET DEFAULT '[]';
ALTER TABLE ONLY ties_data."39a335dca201ef99ae06f4ffd1908b534f8c6c39" ALTER COLUMN "CD_classifiers" SET DEFAULT '[]';
ALTER TABLE ONLY ties_data."39a335dca201ef99ae06f4ffd1908b534f8c6c39" ALTER COLUMN "CD_decorators" SET DEFAULT '{}';

ALTER TABLE ONLY ties_data."39a335dca201ef99ae06f4ffd1908b534f8c6c39" ALTER COLUMN "REL_CD_sourceIds_NRCELLDU_USES_NRSECTORCARRIER" SET DEFAULT '[]';
ALTER TABLE ONLY ties_data."39a335dca201ef99ae06f4ffd1908b534f8c6c39" ALTER COLUMN "REL_CD_classifiers_NRCELLDU_USES_NRSECTORCARRIER" SET DEFAULT '[]';
ALTER TABLE ONLY ties_data."39a335dca201ef99ae06f4ffd1908b534f8c6c39" ALTER COLUMN "REL_CD_decorators_NRCELLDU_USES_NRSECTORCARRIER" SET DEFAULT '{}';

ALTER TABLE ONLY ties_data."39a335dca201ef99ae06f4ffd1908b534f8c6c39" ALTER COLUMN "REL_CD_sourceIds_GNBDUFUNCTION_PROVIDES_NRSECTORCARRIER" SET DEFAULT '[]';
ALTER TABLE ONLY ties_data."39a335dca201ef99ae06f4ffd1908b534f8c6c39" ALTER COLUMN "REL_CD_classifiers_GNBDUFUNCTION_PROVIDES_NRSECTORCARRIER" SET DEFAULT '[]';
ALTER TABLE ONLY ties_data."39a335dca201ef99ae06f4ffd1908b534f8c6c39" ALTER COLUMN "REL_CD_decorators_GNBDUFUNCTION_PROVIDES_NRSECTORCARRIER" SET DEFAULT '{}';

ALTER TABLE ONLY ties_data."39a335dca201ef99ae06f4ffd1908b534f8c6c39" ALTER COLUMN "REL_CD_sourceIds_NRSECTORCARRIER_USES_ANTENNACAPABILITY" SET DEFAULT '[]';
ALTER TABLE ONLY ties_data."39a335dca201ef99ae06f4ffd1908b534f8c6c39" ALTER COLUMN "REL_CD_classifiers_NRSECTORCARRIER_USES_ANTENNACAPABILITY" SET DEFAULT '[]';
ALTER TABLE ONLY ties_data."39a335dca201ef99ae06f4ffd1908b534f8c6c39" ALTER COLUMN "REL_CD_decorators_NRSECTORCARRIER_USES_ANTENNACAPABILITY" SET DEFAULT '{}';


CREATE TABLE IF NOT EXISTS ties_data."o-ran-smo-teiv-ran-cloud_Namespace" (
	"id"			VARCHAR(511),
	"CD_sourceIds"			jsonb,
	"CD_classifiers"			jsonb,
	"CD_decorators"			jsonb,
	"name"			TEXT,
	"REL_FK_deployed-on-nodeCluster"			VARCHAR(511),
	"REL_ID_NAMESPACE_DEPLOYED_ON_NODECLUSTER"			VARCHAR(511),
	"REL_CD_sourceIds_NAMESPACE_DEPLOYED_ON_NODECLUSTER"			jsonb,
	"REL_CD_classifiers_NAMESPACE_DEPLOYED_ON_NODECLUSTER"			jsonb,
	"REL_CD_decorators_NAMESPACE_DEPLOYED_ON_NODECLUSTER"			jsonb
);

ALTER TABLE ONLY ties_data."o-ran-smo-teiv-ran-cloud_Namespace" ALTER COLUMN "CD_sourceIds" SET DEFAULT '[]';
ALTER TABLE ONLY ties_data."o-ran-smo-teiv-ran-cloud_Namespace" ALTER COLUMN "CD_classifiers" SET DEFAULT '[]';
ALTER TABLE ONLY ties_data."o-ran-smo-teiv-ran-cloud_Namespace" ALTER COLUMN "CD_decorators" SET DEFAULT '{}';

ALTER TABLE ONLY ties_data."o-ran-smo-teiv-ran-cloud_Namespace" ALTER COLUMN "REL_CD_sourceIds_NAMESPACE_DEPLOYED_ON_NODECLUSTER" SET DEFAULT '[]';
ALTER TABLE ONLY ties_data."o-ran-smo-teiv-ran-cloud_Namespace" ALTER COLUMN "REL_CD_classifiers_NAMESPACE_DEPLOYED_ON_NODECLUSTER" SET DEFAULT '[]';
ALTER TABLE ONLY ties_data."o-ran-smo-teiv-ran-cloud_Namespace" ALTER COLUMN "REL_CD_decorators_NAMESPACE_DEPLOYED_ON_NODECLUSTER" SET DEFAULT '{}';


CREATE TABLE IF NOT EXISTS ties_data."o-ran-smo-teiv-ran-cloud_NodeCluster" (
	"id"			VARCHAR(511),
	"CD_sourceIds"			jsonb,
	"CD_classifiers"			jsonb,
	"CD_decorators"			jsonb,
	"name"			TEXT,
	"REL_FK_located-at-cloudSite"			VARCHAR(511),
	"REL_ID_NODECLUSTER_LOCATED_AT_CLOUDSITE"			VARCHAR(511),
	"REL_CD_sourceIds_NODECLUSTER_LOCATED_AT_CLOUDSITE"			jsonb,
	"REL_CD_classifiers_NODECLUSTER_LOCATED_AT_CLOUDSITE"			jsonb,
	"REL_CD_decorators_NODECLUSTER_LOCATED_AT_CLOUDSITE"			jsonb
);

ALTER TABLE ONLY ties_data."o-ran-smo-teiv-ran-cloud_NodeCluster" ALTER COLUMN "CD_sourceIds" SET DEFAULT '[]';
ALTER TABLE ONLY ties_data."o-ran-smo-teiv-ran-cloud_NodeCluster" ALTER COLUMN "CD_classifiers" SET DEFAULT '[]';
ALTER TABLE ONLY ties_data."o-ran-smo-teiv-ran-cloud_NodeCluster" ALTER COLUMN "CD_decorators" SET DEFAULT '{}';

ALTER TABLE ONLY ties_data."o-ran-smo-teiv-ran-cloud_NodeCluster" ALTER COLUMN "REL_CD_sourceIds_NODECLUSTER_LOCATED_AT_CLOUDSITE" SET DEFAULT '[]';
ALTER TABLE ONLY ties_data."o-ran-smo-teiv-ran-cloud_NodeCluster" ALTER COLUMN "REL_CD_classifiers_NODECLUSTER_LOCATED_AT_CLOUDSITE" SET DEFAULT '[]';
ALTER TABLE ONLY ties_data."o-ran-smo-teiv-ran-cloud_NodeCluster" ALTER COLUMN "REL_CD_decorators_NODECLUSTER_LOCATED_AT_CLOUDSITE" SET DEFAULT '{}';

CREATE TABLE IF NOT EXISTS ties_data."57a20807ab3f39c86b0b5bf9a819e0881353fa1e" (
	"id"			VARCHAR(511),
	"CD_sourceIds"			jsonb,
	"CD_classifiers"			jsonb,
	"CD_decorators"			jsonb,
	"geo-location"			geography,
	"name"			TEXT,
	"cmId"			jsonb,
	"type"			TEXT,
	"REL_FK_installed-at-site"			VARCHAR(511),
	"REL_ID_PHYSICALNETWORKAPPLIANCE_INSTALLED_AT_SITE"			VARCHAR(511),
	"REL_CD_sourceIds_PHYSICALNETWORKAPPLIANCE_INSTALLED_AT_SITE"			jsonb,
	"REL_CD_classifiers_PHYSICALNETWORKAPPLIANCE_INSTALLED_AT_SITE"			jsonb,
	"REL_CD_decorators_PHYSICALNETWORKAPPLIANCE_INSTALLED_AT_SITE"			jsonb
);

ALTER TABLE ONLY ties_data."57a20807ab3f39c86b0b5bf9a819e0881353fa1e" ALTER COLUMN "CD_sourceIds" SET DEFAULT '[]';
ALTER TABLE ONLY ties_data."57a20807ab3f39c86b0b5bf9a819e0881353fa1e" ALTER COLUMN "CD_classifiers" SET DEFAULT '[]';
ALTER TABLE ONLY ties_data."57a20807ab3f39c86b0b5bf9a819e0881353fa1e" ALTER COLUMN "CD_decorators" SET DEFAULT '{}';

ALTER TABLE ONLY ties_data."57a20807ab3f39c86b0b5bf9a819e0881353fa1e" ALTER COLUMN "REL_CD_sourceIds_PHYSICALNETWORKAPPLIANCE_INSTALLED_AT_SITE" SET DEFAULT '[]';
ALTER TABLE ONLY ties_data."57a20807ab3f39c86b0b5bf9a819e0881353fa1e" ALTER COLUMN "REL_CD_classifiers_PHYSICALNETWORKAPPLIANCE_INSTALLED_AT_SITE" SET DEFAULT '[]';
ALTER TABLE ONLY ties_data."57a20807ab3f39c86b0b5bf9a819e0881353fa1e" ALTER COLUMN "REL_CD_decorators_PHYSICALNETWORKAPPLIANCE_INSTALLED_AT_SITE" SET DEFAULT '{}';


CREATE TABLE IF NOT EXISTS ties_data."22174a23af5d5a96143c83ddfa78654df0acb697" (
	"id"			VARCHAR(511),
	"CD_sourceIds"			jsonb,
	"CD_classifiers"			jsonb,
	"CD_decorators"			jsonb,
	"azimuth"			DECIMAL,
	"geo-location"			geography,
	"sectorId"			BIGINT
);

ALTER TABLE ONLY ties_data."22174a23af5d5a96143c83ddfa78654df0acb697" ALTER COLUMN "CD_sourceIds" SET DEFAULT '[]';
ALTER TABLE ONLY ties_data."22174a23af5d5a96143c83ddfa78654df0acb697" ALTER COLUMN "CD_classifiers" SET DEFAULT '[]';
ALTER TABLE ONLY ties_data."22174a23af5d5a96143c83ddfa78654df0acb697" ALTER COLUMN "CD_decorators" SET DEFAULT '{}';

CREATE TABLE IF NOT EXISTS ties_data."o-ran-smo-teiv-ran-equipment_Site" (
	"id"			VARCHAR(511),
	"CD_sourceIds"			jsonb,
	"CD_classifiers"			jsonb,
	"CD_decorators"			jsonb,
	"name"			TEXT,
	"geo-location"			geography,
	"cmId"			jsonb
);

ALTER TABLE ONLY ties_data."o-ran-smo-teiv-ran-equipment_Site" ALTER COLUMN "CD_sourceIds" SET DEFAULT '[]';
ALTER TABLE ONLY ties_data."o-ran-smo-teiv-ran-equipment_Site" ALTER COLUMN "CD_classifiers" SET DEFAULT '[]';
ALTER TABLE ONLY ties_data."o-ran-smo-teiv-ran-equipment_Site" ALTER COLUMN "CD_decorators" SET DEFAULT '{}';

CREATE TABLE IF NOT EXISTS ties_data."70003c8082751e1832e7bc5c0d83db6d22c4fcdc" (
	"id"			VARCHAR(511),
	"aSide_TestEntityA"			VARCHAR(511),
	"bSide_TestEntityB"			VARCHAR(511),
	"CD_sourceIds"			jsonb,
	"CD_classifiers"			jsonb,
	"CD_decorators"			jsonb
);

ALTER TABLE ONLY ties_data."70003c8082751e1832e7bc5c0d83db6d22c4fcdc" ALTER COLUMN "CD_sourceIds" SET DEFAULT '[]';
ALTER TABLE ONLY ties_data."70003c8082751e1832e7bc5c0d83db6d22c4fcdc" ALTER COLUMN "CD_classifiers" SET DEFAULT '[]';
ALTER TABLE ONLY ties_data."70003c8082751e1832e7bc5c0d83db6d22c4fcdc" ALTER COLUMN "CD_decorators" SET DEFAULT '{}';

CREATE TABLE IF NOT EXISTS ties_data."73936e503f137d82d1422c0f08c66c7ff8b90209" (
	"id"			VARCHAR(511),
	"aSide_TestEntityA"			VARCHAR(511),
	"bSide_TestEntityB"			VARCHAR(511),
	"CD_sourceIds"			jsonb,
	"CD_classifiers"			jsonb,
	"CD_decorators"			jsonb
);

ALTER TABLE ONLY ties_data."73936e503f137d82d1422c0f08c66c7ff8b90209" ALTER COLUMN "CD_sourceIds" SET DEFAULT '[]';
ALTER TABLE ONLY ties_data."73936e503f137d82d1422c0f08c66c7ff8b90209" ALTER COLUMN "CD_classifiers" SET DEFAULT '[]';
ALTER TABLE ONLY ties_data."73936e503f137d82d1422c0f08c66c7ff8b90209" ALTER COLUMN "CD_decorators" SET DEFAULT '{}';

CREATE TABLE IF NOT EXISTS ties_data."o-ran-smo-teiv-ran-logical_TestEntityA" (
	"id"			VARCHAR(511),
	"CD_sourceIds"			jsonb,
	"CD_classifiers"			jsonb,
	"CD_decorators"			jsonb,
	"attribute1"			TEXT
);

ALTER TABLE ONLY ties_data."o-ran-smo-teiv-ran-logical_TestEntityA" ALTER COLUMN "CD_sourceIds" SET DEFAULT '[]';
ALTER TABLE ONLY ties_data."o-ran-smo-teiv-ran-logical_TestEntityA" ALTER COLUMN "CD_classifiers" SET DEFAULT '[]';
ALTER TABLE ONLY ties_data."o-ran-smo-teiv-ran-logical_TestEntityA" ALTER COLUMN "CD_decorators" SET DEFAULT '{}';

CREATE TABLE IF NOT EXISTS ties_data."o-ran-smo-teiv-ran-logical_TestEntityB" (
	"id"			VARCHAR(511),
	"CD_sourceIds"			jsonb,
	"CD_classifiers"			jsonb,
	"CD_decorators"			jsonb,
	"attribute1"			TEXT,
	"REL_FK_used-by-testEntityA"			VARCHAR(511),
	"REL_ID_TESTENTITYA_USES_TESTENTITYB"			VARCHAR(511),
	"REL_CD_sourceIds_TESTENTITYA_USES_TESTENTITYB"			jsonb,
	"REL_CD_classifiers_TESTENTITYA_USES_TESTENTITYB"			jsonb,
	"REL_CD_decorators_TESTENTITYA_USES_TESTENTITYB"			jsonb
);

ALTER TABLE ONLY ties_data."o-ran-smo-teiv-ran-logical_TestEntityB" ALTER COLUMN "CD_sourceIds" SET DEFAULT '[]';
ALTER TABLE ONLY ties_data."o-ran-smo-teiv-ran-logical_TestEntityB" ALTER COLUMN "CD_classifiers" SET DEFAULT '[]';
ALTER TABLE ONLY ties_data."o-ran-smo-teiv-ran-logical_TestEntityB" ALTER COLUMN "CD_decorators" SET DEFAULT '{}';

ALTER TABLE ONLY ties_data."o-ran-smo-teiv-ran-logical_TestEntityB" ALTER COLUMN "REL_CD_sourceIds_TESTENTITYA_USES_TESTENTITYB" SET DEFAULT '[]';
ALTER TABLE ONLY ties_data."o-ran-smo-teiv-ran-logical_TestEntityB" ALTER COLUMN "REL_CD_classifiers_TESTENTITYA_USES_TESTENTITYB" SET DEFAULT '[]';
ALTER TABLE ONLY ties_data."o-ran-smo-teiv-ran-logical_TestEntityB" ALTER COLUMN "REL_CD_decorators_TESTENTITYA_USES_TESTENTITYB" SET DEFAULT '{}';

SELECT ties_data.create_constraint_if_not_exists(
	'70003c8082751e1832e7bc5c0d83db6d22c4fcdc',
 'PK_TESTENTITYA_GROUPS_TESTENTITYB_id',
 'ALTER TABLE ties_data."70003c8082751e1832e7bc5c0d83db6d22c4fcdc" ADD CONSTRAINT "PK_TESTENTITYA_GROUPS_TESTENTITYB_id" PRIMARY KEY ("id");'
);

SELECT ties_data.create_constraint_if_not_exists(
	'73936e503f137d82d1422c0f08c66c7ff8b90209',
 'PK_TESTENTITYA_PROVIDES_TESTENTITYB_id',
 'ALTER TABLE ties_data."73936e503f137d82d1422c0f08c66c7ff8b90209" ADD CONSTRAINT "PK_TESTENTITYA_PROVIDES_TESTENTITYB_id" PRIMARY KEY ("id");'
);

SELECT ties_data.create_constraint_if_not_exists(
	'o-ran-smo-teiv-ran-logical_TestEntityA',
 'PK_TestEntityA_id',
 'ALTER TABLE ties_data."o-ran-smo-teiv-ran-logical_TestEntityA" ADD CONSTRAINT "PK_TestEntityA_id" PRIMARY KEY ("id");'
);

SELECT ties_data.create_constraint_if_not_exists(
	'o-ran-smo-teiv-ran-logical_TestEntityB',
 'PK_TestEntityB_id',
 'ALTER TABLE ties_data."o-ran-smo-teiv-ran-logical_TestEntityB" ADD CONSTRAINT "PK_TestEntityB_id" PRIMARY KEY ("id");'
);

SELECT ties_data.create_constraint_if_not_exists(
	'70003c8082751e1832e7bc5c0d83db6d22c4fcdc',
 'FK_TESTENTITYA_GROUPS_TESTENTITYB_aSide_TestEntityA',
 'ALTER TABLE ties_data."70003c8082751e1832e7bc5c0d83db6d22c4fcdc" ADD CONSTRAINT "FK_TESTENTITYA_GROUPS_TESTENTITYB_aSide_TestEntityA" FOREIGN KEY ("aSide_TestEntityA") REFERENCES ties_data."o-ran-smo-teiv-ran-logical_TestEntityA" (id) ON DELETE CASCADE;'
);

SELECT ties_data.create_constraint_if_not_exists(
	'70003c8082751e1832e7bc5c0d83db6d22c4fcdc',
 'FK_TESTENTITYA_GROUPS_TESTENTITYB_bSide_TestEntityB',
 'ALTER TABLE ties_data."70003c8082751e1832e7bc5c0d83db6d22c4fcdc" ADD CONSTRAINT "FK_TESTENTITYA_GROUPS_TESTENTITYB_bSide_TestEntityB" FOREIGN KEY ("bSide_TestEntityB") REFERENCES ties_data."o-ran-smo-teiv-ran-logical_TestEntityB" (id) ON DELETE CASCADE;'
);

SELECT ties_data.create_constraint_if_not_exists(
	'73936e503f137d82d1422c0f08c66c7ff8b90209',
 'FK_TESTENTITYA_PROVIDES_TESTENTITYB_aSide_TestEntityA',
 'ALTER TABLE ties_data."73936e503f137d82d1422c0f08c66c7ff8b90209" ADD CONSTRAINT "FK_TESTENTITYA_PROVIDES_TESTENTITYB_aSide_TestEntityA" FOREIGN KEY ("aSide_TestEntityA") REFERENCES ties_data."o-ran-smo-teiv-ran-logical_TestEntityA" (id) ON DELETE CASCADE;'
);

SELECT ties_data.create_constraint_if_not_exists(
	'73936e503f137d82d1422c0f08c66c7ff8b90209',
 'FK_TESTENTITYA_PROVIDES_TESTENTITYB_bSide_TestEntityB',
 'ALTER TABLE ties_data."73936e503f137d82d1422c0f08c66c7ff8b90209" ADD CONSTRAINT "FK_TESTENTITYA_PROVIDES_TESTENTITYB_bSide_TestEntityB" FOREIGN KEY ("bSide_TestEntityB") REFERENCES ties_data."o-ran-smo-teiv-ran-logical_TestEntityB" (id) ON DELETE CASCADE;'
);

SELECT ties_data.create_constraint_if_not_exists(
	'o-ran-smo-teiv-ran-logical_TestEntityB',
 'FK_TestEntityB_REL_FK_used-by-testEntityA',
 'ALTER TABLE ties_data."o-ran-smo-teiv-ran-logical_TestEntityB" ADD CONSTRAINT "FK_TestEntityB_REL_FK_used-by-testEntityA" FOREIGN KEY ("REL_FK_used-by-testEntityA") REFERENCES ties_data."o-ran-smo-teiv-ran-logical_TestEntityA" (id) ON DELETE CASCADE;'
);

SELECT ties_data.create_constraint_if_not_exists(
	'o-ran-smo-teiv-ran-logical_TestEntityB',
 'UNIQUE_TestEntityB_REL_ID_TESTENTITYA_USES_TESTENTITYB',
 'ALTER TABLE ties_data."o-ran-smo-teiv-ran-logical_TestEntityB" ADD CONSTRAINT "UNIQUE_TestEntityB_REL_ID_TESTENTITYA_USES_TESTENTITYB" UNIQUE ("REL_ID_TESTENTITYA_USES_TESTENTITYB");'
);

ALTER TABLE ONLY ties_data."o-ran-smo-teiv-ran-equipment_Site" ALTER COLUMN "CD_sourceIds" SET DEFAULT '[]';
ALTER TABLE ONLY ties_data."o-ran-smo-teiv-ran-equipment_Site" ALTER COLUMN "CD_classifiers" SET DEFAULT '[]';
ALTER TABLE ONLY ties_data."o-ran-smo-teiv-ran-equipment_Site" ALTER COLUMN "CD_decorators" SET DEFAULT '{}';

CREATE TABLE IF NOT EXISTS ties_data."341622dca4e0350289717b52df5883edc3fa0280" (
	"id"			VARCHAR(511),
	"fdn"			TEXT,
	"CD_sourceIds"			jsonb,
	"CD_classifiers"			jsonb,
	"CD_decorators"			jsonb
);

ALTER TABLE ONLY ties_data."341622dca4e0350289717b52df5883edc3fa0280" ALTER COLUMN "CD_sourceIds" SET DEFAULT '[]';
ALTER TABLE ONLY ties_data."341622dca4e0350289717b52df5883edc3fa0280" ALTER COLUMN "CD_classifiers" SET DEFAULT '[]';
ALTER TABLE ONLY ties_data."341622dca4e0350289717b52df5883edc3fa0280" ALTER COLUMN "CD_decorators" SET DEFAULT '{}';

SELECT ties_data.create_constraint_if_not_exists(
	'ef701af8e1445ed5d377664ba1d3d1c645e31639',
 'PK_F568C5029499EE188A168886B2EF09C0D1FAAA9F',
 'ALTER TABLE ties_data."ef701af8e1445ed5d377664ba1d3d1c645e31639" ADD CONSTRAINT "PK_F568C5029499EE188A168886B2EF09C0D1FAAA9F" PRIMARY KEY ("id");'
);

SELECT ties_data.create_constraint_if_not_exists(
	'fa2dceaf53e045c136ce9db9bc5faae65a29fa4d',
 'PK_19E2CBE3A8BBA12A7D9EC9923573BC0A65B1EC4A',
 'ALTER TABLE ties_data."fa2dceaf53e045c136ce9db9bc5faae65a29fa4d" ADD CONSTRAINT "PK_19E2CBE3A8BBA12A7D9EC9923573BC0A65B1EC4A" PRIMARY KEY ("id");'
);

SELECT ties_data.create_constraint_if_not_exists(
	'5f8facd51b2bbddc90d9dee9be697907441892d0',
 'PK_F52E445B46B712C0D9014D194AB039C205E69818',
 'ALTER TABLE ties_data."5f8facd51b2bbddc90d9dee9be697907441892d0" ADD CONSTRAINT "PK_F52E445B46B712C0D9014D194AB039C205E69818" PRIMARY KEY ("id");'
);

SELECT ties_data.create_constraint_if_not_exists(
	'300672c8a708d6af0b9af2f9accdff5e6e005721',
 'PK_CCB39BED50FEF60B1B1F86A7C938BE89B7D90D38',
 'ALTER TABLE ties_data."300672c8a708d6af0b9af2f9accdff5e6e005721" ADD CONSTRAINT "PK_CCB39BED50FEF60B1B1F86A7C938BE89B7D90D38" PRIMARY KEY ("id");'
);

SELECT ties_data.create_constraint_if_not_exists(
	'bc563e4310b0538e6bdd35f52684160af5b23671',
 'PK_77881E9D6F659316F836050DDC6E26FA4DE425EE',
 'ALTER TABLE ties_data."bc563e4310b0538e6bdd35f52684160af5b23671" ADD CONSTRAINT "PK_77881E9D6F659316F836050DDC6E26FA4DE425EE" PRIMARY KEY ("id");'
);

SELECT ties_data.create_constraint_if_not_exists(
	'3fdb9cd7557edf559a0e4de88df220e7545884b5',
 'PK_079D5D67E043B09F9C7CD4F6EA1DB12688D43F69',
 'ALTER TABLE ties_data."3fdb9cd7557edf559a0e4de88df220e7545884b5" ADD CONSTRAINT "PK_079D5D67E043B09F9C7CD4F6EA1DB12688D43F69" PRIMARY KEY ("id");'
);

SELECT ties_data.create_constraint_if_not_exists(
	'f86057a8762a50b1c7fb07af9d5c001bffaefd15',
 'PK_5D1AC46C58E1FE44FB266F86CE79B3AEBE1D92B3',
 'ALTER TABLE ties_data."f86057a8762a50b1c7fb07af9d5c001bffaefd15" ADD CONSTRAINT "PK_5D1AC46C58E1FE44FB266F86CE79B3AEBE1D92B3" PRIMARY KEY ("id");'
);

SELECT ties_data.create_constraint_if_not_exists(
	'5b8a47d4a8297a0a1d31e091af06e26d25ef6caf',
 'PK_5b8a47d4a8297a0a1d31e091af06e26d25ef6caf_id',
 'ALTER TABLE ties_data."5b8a47d4a8297a0a1d31e091af06e26d25ef6caf" ADD CONSTRAINT "PK_5b8a47d4a8297a0a1d31e091af06e26d25ef6caf_id" PRIMARY KEY ("id");'
);

SELECT ties_data.create_constraint_if_not_exists(
	'88f1bd76c7a935fb505cf235e6819f46c55ec98a',
 'PK_AntennaCapability_id',
 'ALTER TABLE ties_data."88f1bd76c7a935fb505cf235e6819f46c55ec98a" ADD CONSTRAINT "PK_AntennaCapability_id" PRIMARY KEY ("id");'
);

SELECT ties_data.create_constraint_if_not_exists(
	'f8caf5ebe876c3001d67efe06e4d83abf0babe31',
 'PK_AntennaModule_id',
 'ALTER TABLE ties_data."f8caf5ebe876c3001d67efe06e4d83abf0babe31" ADD CONSTRAINT "PK_AntennaModule_id" PRIMARY KEY ("id");'
);

SELECT ties_data.create_constraint_if_not_exists(
	'e01fcb87ad2c34ce66c34420255e25aaca270e5e',
 'PK_CloudNativeApplication_id',
 'ALTER TABLE ties_data."e01fcb87ad2c34ce66c34420255e25aaca270e5e" ADD CONSTRAINT "PK_CloudNativeApplication_id" PRIMARY KEY ("id");'
);

SELECT ties_data.create_constraint_if_not_exists(
	'163276fa439cdfccabb80f7acacb6fa638e8d314',
 'PK_CloudNativeSystem_id',
 'ALTER TABLE ties_data."163276fa439cdfccabb80f7acacb6fa638e8d314" ADD CONSTRAINT "PK_CloudNativeSystem_id" PRIMARY KEY ("id");'
);

SELECT ties_data.create_constraint_if_not_exists(
	'o-ran-smo-teiv-ran-cloud_CloudSite',
 'PK_CloudSite_id',
 'ALTER TABLE ties_data."o-ran-smo-teiv-ran-cloud_CloudSite" ADD CONSTRAINT "PK_CloudSite_id" PRIMARY KEY ("id");'
);

SELECT ties_data.create_constraint_if_not_exists(
	'o-ran-smo-teiv-ran-logical_ENodeBFunction',
 'PK_ENodeBFunction_id',
 'ALTER TABLE ties_data."o-ran-smo-teiv-ran-logical_ENodeBFunction" ADD CONSTRAINT "PK_ENodeBFunction_id" PRIMARY KEY ("id");'
);

SELECT ties_data.create_constraint_if_not_exists(
	'o-ran-smo-teiv-ran-logical_EUtranCell',
 'PK_EUtranCell_id',
 'ALTER TABLE ties_data."o-ran-smo-teiv-ran-logical_EUtranCell" ADD CONSTRAINT "PK_EUtranCell_id" PRIMARY KEY ("id");'
);

SELECT ties_data.create_constraint_if_not_exists(
	'7cd7062ea24531b2f48e4f2fdc51eaf0b82f88c7',
 'PK_GNBCUCPFUNCTION_REALISED_BY_CLOUDNATIVEAPPLICATION_id',
 'ALTER TABLE ties_data."7cd7062ea24531b2f48e4f2fdc51eaf0b82f88c7" ADD CONSTRAINT "PK_GNBCUCPFUNCTION_REALISED_BY_CLOUDNATIVEAPPLICATION_id" PRIMARY KEY ("id");'
);

SELECT ties_data.create_constraint_if_not_exists(
	'c4a425179d3089b5288fdf059079d0ea26977f0f',
 'PK_GNBCUCPFunction_id',
 'ALTER TABLE ties_data."c4a425179d3089b5288fdf059079d0ea26977f0f" ADD CONSTRAINT "PK_GNBCUCPFunction_id" PRIMARY KEY ("id");'
);

SELECT ties_data.create_constraint_if_not_exists(
	'70a4a84bca01ea022ab24d8cb82422c572922675',
 'PK_GNBCUUPFUNCTION_REALISED_BY_CLOUDNATIVEAPPLICATION_id',
 'ALTER TABLE ties_data."70a4a84bca01ea022ab24d8cb82422c572922675" ADD CONSTRAINT "PK_GNBCUUPFUNCTION_REALISED_BY_CLOUDNATIVEAPPLICATION_id" PRIMARY KEY ("id");'
);

SELECT ties_data.create_constraint_if_not_exists(
	'8fe520ccd54b8f72ef7b2d3061264ddc2481e4eb',
 'PK_GNBCUUPFunction_id',
 'ALTER TABLE ties_data."8fe520ccd54b8f72ef7b2d3061264ddc2481e4eb" ADD CONSTRAINT "PK_GNBCUUPFunction_id" PRIMARY KEY ("id");'
);

SELECT ties_data.create_constraint_if_not_exists(
	'10484f157f490eb5b27e40dbfaf4d5f2be17c57c',
 'PK_GNBDUFUNCTION_REALISED_BY_CLOUDNATIVEAPPLICATION_id',
 'ALTER TABLE ties_data."10484f157f490eb5b27e40dbfaf4d5f2be17c57c" ADD CONSTRAINT "PK_GNBDUFUNCTION_REALISED_BY_CLOUDNATIVEAPPLICATION_id" PRIMARY KEY ("id");'
);

SELECT ties_data.create_constraint_if_not_exists(
	'o-ran-smo-teiv-ran-logical_GNBDUFunction',
 'PK_GNBDUFunction_id',
 'ALTER TABLE ties_data."o-ran-smo-teiv-ran-logical_GNBDUFunction" ADD CONSTRAINT "PK_GNBDUFunction_id" PRIMARY KEY ("id");'
);

SELECT ties_data.create_constraint_if_not_exists(
	'c88307168935f02fdecc084ea5040bb9db16c701',
 'PK_LTESectorCarrier_id',
 'ALTER TABLE ties_data."c88307168935f02fdecc084ea5040bb9db16c701" ADD CONSTRAINT "PK_LTESectorCarrier_id" PRIMARY KEY ("id");'
);

SELECT ties_data.create_constraint_if_not_exists(
	'o-ran-smo-teiv-ran-oam_ManagedElement',
 'PK_ManagedElement_id',
 'ALTER TABLE ties_data."o-ran-smo-teiv-ran-oam_ManagedElement" ADD CONSTRAINT "PK_ManagedElement_id" PRIMARY KEY ("id");'
);

SELECT ties_data.create_constraint_if_not_exists(
	'o-ran-smo-teiv-ran-logical_NRCellCU',
 'PK_NRCellCU_id',
 'ALTER TABLE ties_data."o-ran-smo-teiv-ran-logical_NRCellCU" ADD CONSTRAINT "PK_NRCellCU_id" PRIMARY KEY ("id");'
);

SELECT ties_data.create_constraint_if_not_exists(
	'o-ran-smo-teiv-ran-logical_NRCellDU',
 'PK_NRCellDU_id',
 'ALTER TABLE ties_data."o-ran-smo-teiv-ran-logical_NRCellDU" ADD CONSTRAINT "PK_NRCellDU_id" PRIMARY KEY ("id");'
);

SELECT ties_data.create_constraint_if_not_exists(
	'39a335dca201ef99ae06f4ffd1908b534f8c6c39',
 'PK_NRSectorCarrier_id',
 'ALTER TABLE ties_data."39a335dca201ef99ae06f4ffd1908b534f8c6c39" ADD CONSTRAINT "PK_NRSectorCarrier_id" PRIMARY KEY ("id");'
);

SELECT ties_data.create_constraint_if_not_exists(
	'o-ran-smo-teiv-ran-cloud_Namespace',
 'PK_Namespace_id',
 'ALTER TABLE ties_data."o-ran-smo-teiv-ran-cloud_Namespace" ADD CONSTRAINT "PK_Namespace_id" PRIMARY KEY ("id");'
);

SELECT ties_data.create_constraint_if_not_exists(
	'o-ran-smo-teiv-ran-cloud_NodeCluster',
 'PK_NodeCluster_id',
 'ALTER TABLE ties_data."o-ran-smo-teiv-ran-cloud_NodeCluster" ADD CONSTRAINT "PK_NodeCluster_id" PRIMARY KEY ("id");'
);

SELECT ties_data.create_constraint_if_not_exists(
	'57a20807ab3f39c86b0b5bf9a819e0881353fa1e',
 'PK_PhysicalNetworkAppliance_id',
 'ALTER TABLE ties_data."57a20807ab3f39c86b0b5bf9a819e0881353fa1e" ADD CONSTRAINT "PK_PhysicalNetworkAppliance_id" PRIMARY KEY ("id");'
);

SELECT ties_data.create_constraint_if_not_exists(
	'22174a23af5d5a96143c83ddfa78654df0acb697',
 'PK_Sector_id',
 'ALTER TABLE ties_data."22174a23af5d5a96143c83ddfa78654df0acb697" ADD CONSTRAINT "PK_Sector_id" PRIMARY KEY ("id");'
);

SELECT ties_data.create_constraint_if_not_exists(
	'o-ran-smo-teiv-ran-equipment_Site',
 'PK_Site_id',
 'ALTER TABLE ties_data."o-ran-smo-teiv-ran-equipment_Site" ADD CONSTRAINT "PK_Site_id" PRIMARY KEY ("id");'
);

SELECT ties_data.create_constraint_if_not_exists(
	'ef701af8e1445ed5d377664ba1d3d1c645e31639',
 'FK_54FE608944AC8EFFFBE7E55744B8BA52F6B29ABB',
 'ALTER TABLE ties_data."ef701af8e1445ed5d377664ba1d3d1c645e31639" ADD CONSTRAINT "FK_54FE608944AC8EFFFBE7E55744B8BA52F6B29ABB" FOREIGN KEY ("REL_FK_C2F5EC33C0760F653CE7263A49C0B697FCA2D542") REFERENCES ties_data."fa2dceaf53e045c136ce9db9bc5faae65a29fa4d" (id) ON DELETE CASCADE;'
);

SELECT ties_data.create_constraint_if_not_exists(
	'fa2dceaf53e045c136ce9db9bc5faae65a29fa4d',
 'FK_9C091709D40D51DEE4DC87A44695F6EBA2E965DE',
 'ALTER TABLE ties_data."fa2dceaf53e045c136ce9db9bc5faae65a29fa4d" ADD CONSTRAINT "FK_9C091709D40D51DEE4DC87A44695F6EBA2E965DE" FOREIGN KEY ("REL_FK_26958E3A529C4C8B68A29FDA906F8CD290F66078") REFERENCES ties_data."ef701af8e1445ed5d377664ba1d3d1c645e31639" (id) ON DELETE CASCADE;'
);

SELECT ties_data.create_constraint_if_not_exists(
	'fa2dceaf53e045c136ce9db9bc5faae65a29fa4d',
 'UNIQUE_9A721779BB5547778B9258ACD73261B9AABFF302',
 'ALTER TABLE ties_data."fa2dceaf53e045c136ce9db9bc5faae65a29fa4d" ADD CONSTRAINT "UNIQUE_9A721779BB5547778B9258ACD73261B9AABFF302" UNIQUE ("REL_ID_B7945BFD83380F3E12CF99F2B0F838F364027F92");'
);

SELECT ties_data.create_constraint_if_not_exists(
	'5f8facd51b2bbddc90d9dee9be697907441892d0',
 'FK_899FCB466B0BBCC040E945A3E746F5DE53CCCB29',
 'ALTER TABLE ties_data."5f8facd51b2bbddc90d9dee9be697907441892d0" ADD CONSTRAINT "FK_899FCB466B0BBCC040E945A3E746F5DE53CCCB29" FOREIGN KEY ("REL_FK_AB87B417CCD05C332DDD0C60F0C6AB41D38B05E5") REFERENCES ties_data."fa2dceaf53e045c136ce9db9bc5faae65a29fa4d" (id) ON DELETE CASCADE;'
);

SELECT ties_data.create_constraint_if_not_exists(
	'5f8facd51b2bbddc90d9dee9be697907441892d0',
 'UNIQUE_3DDA71C08F678AA7303FE0BD127CC27A80D1DDED',
 'ALTER TABLE ties_data."5f8facd51b2bbddc90d9dee9be697907441892d0" ADD CONSTRAINT "UNIQUE_3DDA71C08F678AA7303FE0BD127CC27A80D1DDED" UNIQUE ("REL_ID_FC2F6A5A12917357B548C83F4B0C1AD58FA61413");'
);

SELECT ties_data.create_constraint_if_not_exists(
	'5f8facd51b2bbddc90d9dee9be697907441892d0',
 'FK_E33FB71E6FAC69C92ADEEC55E63D401D21DF91AE',
 'ALTER TABLE ties_data."5f8facd51b2bbddc90d9dee9be697907441892d0" ADD CONSTRAINT "FK_E33FB71E6FAC69C92ADEEC55E63D401D21DF91AE" FOREIGN KEY ("REL_FK_8C98B70070BBD11F90F192DDA3ECF6302390E956") REFERENCES ties_data."bc563e4310b0538e6bdd35f52684160af5b23671" (id) ON DELETE CASCADE;'
);

SELECT ties_data.create_constraint_if_not_exists(
	'5f8facd51b2bbddc90d9dee9be697907441892d0',
 'UNIQUE_287E65679DC2108F55F43D62A4325F6DECF372E1',
 'ALTER TABLE ties_data."5f8facd51b2bbddc90d9dee9be697907441892d0" ADD CONSTRAINT "UNIQUE_287E65679DC2108F55F43D62A4325F6DECF372E1" UNIQUE ("REL_ID_AFBF10D23507AD3B6408947D2A9AF8465BA7B08C");'
);

SELECT ties_data.create_constraint_if_not_exists(
	'300672c8a708d6af0b9af2f9accdff5e6e005721',
 'FK_D43434F9F6FD1C14BE14A0EEDA4C9918B26E82F1',
 'ALTER TABLE ties_data."300672c8a708d6af0b9af2f9accdff5e6e005721" ADD CONSTRAINT "FK_D43434F9F6FD1C14BE14A0EEDA4C9918B26E82F1" FOREIGN KEY ("REL_FK_609963BFEE15FF824280FBE201313C3CDACDDDCE") REFERENCES ties_data."3fdb9cd7557edf559a0e4de88df220e7545884b5" (id) ON DELETE CASCADE;'
);

SELECT ties_data.create_constraint_if_not_exists(
	'300672c8a708d6af0b9af2f9accdff5e6e005721',
 'UNIQUE_4E6028C8AF5DB6D082B612C5CBB5B32A943C0AAD',
 'ALTER TABLE ties_data."300672c8a708d6af0b9af2f9accdff5e6e005721" ADD CONSTRAINT "UNIQUE_4E6028C8AF5DB6D082B612C5CBB5B32A943C0AAD" UNIQUE ("REL_ID_040FC8B06B420BA5708AF4798102D1E65FB4DC61");'
);

SELECT ties_data.create_constraint_if_not_exists(
	'3fdb9cd7557edf559a0e4de88df220e7545884b5',
 'FK_C5EB2FEB41FDD27A7CED04A3FD665B4BDEF994F5',
 'ALTER TABLE ties_data."3fdb9cd7557edf559a0e4de88df220e7545884b5" ADD CONSTRAINT "FK_C5EB2FEB41FDD27A7CED04A3FD665B4BDEF994F5" FOREIGN KEY ("REL_FK_48B14FA5B787C6398AD1DE5EE670AD0D2A2CB36F") REFERENCES ties_data."fa2dceaf53e045c136ce9db9bc5faae65a29fa4d" (id) ON DELETE CASCADE;'
);

SELECT ties_data.create_constraint_if_not_exists(
	'3fdb9cd7557edf559a0e4de88df220e7545884b5',
 'UNIQUE_176E72F1225D7EEFC222D87B6EC4D66DD968BD13',
 'ALTER TABLE ties_data."3fdb9cd7557edf559a0e4de88df220e7545884b5" ADD CONSTRAINT "UNIQUE_176E72F1225D7EEFC222D87B6EC4D66DD968BD13" UNIQUE ("REL_ID_BDE0B6C74D14AC109D29A08D80E92D4D0DCAEB0B");'
);

SELECT ties_data.create_constraint_if_not_exists(
	'f86057a8762a50b1c7fb07af9d5c001bffaefd15',
 'FK_BFC9C18D6DBCD1FFC021B021CF31444EAA1FEDCA',
 'ALTER TABLE ties_data."f86057a8762a50b1c7fb07af9d5c001bffaefd15" ADD CONSTRAINT "FK_BFC9C18D6DBCD1FFC021B021CF31444EAA1FEDCA" FOREIGN KEY ("aSide_B0FD0521695A211BFF76F413A31F28CBA32E57ED") REFERENCES ties_data."3fdb9cd7557edf559a0e4de88df220e7545884b5" (id) ON DELETE CASCADE;'
);

SELECT ties_data.create_constraint_if_not_exists(
	'f86057a8762a50b1c7fb07af9d5c001bffaefd15',
 'FK_EADC754A352728E72F7320F69D802725C71EDE3E',
 'ALTER TABLE ties_data."f86057a8762a50b1c7fb07af9d5c001bffaefd15" ADD CONSTRAINT "FK_EADC754A352728E72F7320F69D802725C71EDE3E" FOREIGN KEY ("bSide_84EF1134719BB6FCF33A94FF770311FC722BCF41") REFERENCES ties_data."5f8facd51b2bbddc90d9dee9be697907441892d0" (id) ON DELETE CASCADE;'
);

SELECT ties_data.create_constraint_if_not_exists(
	'5b8a47d4a8297a0a1d31e091af06e26d25ef6caf',
 'FK_03713853A2B7ACDC198858CAFBFF355026FEA0B3',
 'ALTER TABLE ties_data."5b8a47d4a8297a0a1d31e091af06e26d25ef6caf" ADD CONSTRAINT "FK_03713853A2B7ACDC198858CAFBFF355026FEA0B3" FOREIGN KEY ("aSide_AntennaCapability") REFERENCES ties_data."88f1bd76c7a935fb505cf235e6819f46c55ec98a" (id) ON DELETE CASCADE;'
);

SELECT ties_data.create_constraint_if_not_exists(
	'5b8a47d4a8297a0a1d31e091af06e26d25ef6caf',
 'FK_5059CE8D2FEE5A1FAD9E06F4FAAFC148BAEA70E3',
 'ALTER TABLE ties_data."5b8a47d4a8297a0a1d31e091af06e26d25ef6caf" ADD CONSTRAINT "FK_5059CE8D2FEE5A1FAD9E06F4FAAFC148BAEA70E3" FOREIGN KEY ("bSide_AntennaModule") REFERENCES ties_data."f8caf5ebe876c3001d67efe06e4d83abf0babe31" (id) ON DELETE CASCADE;'
);

SELECT ties_data.create_constraint_if_not_exists(
	'88f1bd76c7a935fb505cf235e6819f46c55ec98a',
 'FK_AntennaCapability_REL_FK_used-by-lteSectorCarrier',
 'ALTER TABLE ties_data."88f1bd76c7a935fb505cf235e6819f46c55ec98a" ADD CONSTRAINT "FK_AntennaCapability_REL_FK_used-by-lteSectorCarrier" FOREIGN KEY ("REL_FK_used-by-lteSectorCarrier") REFERENCES ties_data."c88307168935f02fdecc084ea5040bb9db16c701" (id) ON DELETE CASCADE;'
);

SELECT ties_data.create_constraint_if_not_exists(
	'f8caf5ebe876c3001d67efe06e4d83abf0babe31',
 'FK_AntennaModule_REL_FK_grouped-by-sector',
 'ALTER TABLE ties_data."f8caf5ebe876c3001d67efe06e4d83abf0babe31" ADD CONSTRAINT "FK_AntennaModule_REL_FK_grouped-by-sector" FOREIGN KEY ("REL_FK_grouped-by-sector") REFERENCES ties_data."22174a23af5d5a96143c83ddfa78654df0acb697" (id) ON DELETE CASCADE;'
);

SELECT ties_data.create_constraint_if_not_exists(
	'f8caf5ebe876c3001d67efe06e4d83abf0babe31',
 'UNIQUE_AntennaModule_REL_ID_SECTOR_GROUPS_ANTENNAMODULE',
 'ALTER TABLE ties_data."f8caf5ebe876c3001d67efe06e4d83abf0babe31" ADD CONSTRAINT "UNIQUE_AntennaModule_REL_ID_SECTOR_GROUPS_ANTENNAMODULE" UNIQUE ("REL_ID_SECTOR_GROUPS_ANTENNAMODULE");'
);

SELECT ties_data.create_constraint_if_not_exists(
	'f8caf5ebe876c3001d67efe06e4d83abf0babe31',
 'FK_AntennaModule_REL_FK_installed-at-site',
 'ALTER TABLE ties_data."f8caf5ebe876c3001d67efe06e4d83abf0babe31" ADD CONSTRAINT "FK_AntennaModule_REL_FK_installed-at-site" FOREIGN KEY ("REL_FK_installed-at-site") REFERENCES ties_data."o-ran-smo-teiv-ran-equipment_Site" (id) ON DELETE CASCADE;'
);

SELECT ties_data.create_constraint_if_not_exists(
	'f8caf5ebe876c3001d67efe06e4d83abf0babe31',
 'UNIQUE_AntennaModule_REL_ID_ANTENNAMODULE_INSTALLED_AT_SITE',
 'ALTER TABLE ties_data."f8caf5ebe876c3001d67efe06e4d83abf0babe31" ADD CONSTRAINT "UNIQUE_AntennaModule_REL_ID_ANTENNAMODULE_INSTALLED_AT_SITE" UNIQUE ("REL_ID_ANTENNAMODULE_INSTALLED_AT_SITE");'
);

SELECT ties_data.create_constraint_if_not_exists(
	'e01fcb87ad2c34ce66c34420255e25aaca270e5e',
 'FK_CloudNativeApplication_REL_FK_realised-managedElement',
 'ALTER TABLE ties_data."e01fcb87ad2c34ce66c34420255e25aaca270e5e" ADD CONSTRAINT "FK_CloudNativeApplication_REL_FK_realised-managedElement" FOREIGN KEY ("REL_FK_realised-managedElement") REFERENCES ties_data."o-ran-smo-teiv-ran-oam_ManagedElement" (id) ON DELETE CASCADE;'
);

SELECT ties_data.create_constraint_if_not_exists(
	'e01fcb87ad2c34ce66c34420255e25aaca270e5e',
 'UNIQUE_DAB3C12479849DA6C222B812C2A8CD1535D0C186',
 'ALTER TABLE ties_data."e01fcb87ad2c34ce66c34420255e25aaca270e5e" ADD CONSTRAINT "UNIQUE_DAB3C12479849DA6C222B812C2A8CD1535D0C186" UNIQUE ("REL_ID_MANAGEDELEMENT_REALISED_BY_CLOUDNATIVEAPPLICATION");'
);

SELECT ties_data.create_constraint_if_not_exists(
	'e01fcb87ad2c34ce66c34420255e25aaca270e5e',
 'FK_CloudNativeApplication_REL_FK_comprised-by-cloudNativeSystem',
 'ALTER TABLE ties_data."e01fcb87ad2c34ce66c34420255e25aaca270e5e" ADD CONSTRAINT "FK_CloudNativeApplication_REL_FK_comprised-by-cloudNativeSystem" FOREIGN KEY ("REL_FK_comprised-by-cloudNativeSystem") REFERENCES ties_data."e01fcb87ad2c34ce66c34420255e25aaca270e5e" (id) ON DELETE CASCADE;'
);

SELECT ties_data.create_constraint_if_not_exists(
	'e01fcb87ad2c34ce66c34420255e25aaca270e5e',
 'UNIQUE_F2774BC0806E925ADA0B1CAA50B5A41DFB7BF79A',
 'ALTER TABLE ties_data."e01fcb87ad2c34ce66c34420255e25aaca270e5e" ADD CONSTRAINT "UNIQUE_F2774BC0806E925ADA0B1CAA50B5A41DFB7BF79A" UNIQUE ("REL_ID_CLOUDNATIVESYSTEM_COMPRISES_CLOUDNATIVEAPPLICATION");'
);

SELECT ties_data.create_constraint_if_not_exists(
	'e01fcb87ad2c34ce66c34420255e25aaca270e5e',
 'FK_CloudNativeApplication_REL_FK_deployed-on-namespace',
 'ALTER TABLE ties_data."e01fcb87ad2c34ce66c34420255e25aaca270e5e" ADD CONSTRAINT "FK_CloudNativeApplication_REL_FK_deployed-on-namespace" FOREIGN KEY ("REL_FK_deployed-on-namespace") REFERENCES ties_data."o-ran-smo-teiv-ran-cloud_Namespace" (id) ON DELETE CASCADE;'
);

SELECT ties_data.create_constraint_if_not_exists(
	'e01fcb87ad2c34ce66c34420255e25aaca270e5e',
 'UNIQUE_1A317D31DA93B0CF9A9F8A04077B0F60ABCFF49C',
 'ALTER TABLE ties_data."e01fcb87ad2c34ce66c34420255e25aaca270e5e" ADD CONSTRAINT "UNIQUE_1A317D31DA93B0CF9A9F8A04077B0F60ABCFF49C" UNIQUE ("REL_ID_CLOUDNATIVEAPPLICATION_DEPLOYED_ON_NAMESPACE");'
);

SELECT ties_data.create_constraint_if_not_exists(
	'163276fa439cdfccabb80f7acacb6fa638e8d314',
 'FK_CloudNativeSystem_REL_FK_deployed-managedElement',
 'ALTER TABLE ties_data."163276fa439cdfccabb80f7acacb6fa638e8d314" ADD CONSTRAINT "FK_CloudNativeSystem_REL_FK_deployed-managedElement" FOREIGN KEY ("REL_FK_deployed-managedElement") REFERENCES ties_data."o-ran-smo-teiv-ran-oam_ManagedElement" (id) ON DELETE CASCADE;'
);

SELECT ties_data.create_constraint_if_not_exists(
	'o-ran-smo-teiv-ran-logical_ENodeBFunction',
 'FK_ENodeBFunction_REL_FK_managed-by-managedElement',
 'ALTER TABLE ties_data."o-ran-smo-teiv-ran-logical_ENodeBFunction" ADD CONSTRAINT "FK_ENodeBFunction_REL_FK_managed-by-managedElement" FOREIGN KEY ("REL_FK_managed-by-managedElement") REFERENCES ties_data."o-ran-smo-teiv-ran-oam_ManagedElement" (id) ON DELETE CASCADE;'
);

SELECT ties_data.create_constraint_if_not_exists(
	'o-ran-smo-teiv-ran-logical_ENodeBFunction',
 'UNIQUE_F33037EE8037D0606D15FFB45EE8A27FD6DE30EE',
 'ALTER TABLE ties_data."o-ran-smo-teiv-ran-logical_ENodeBFunction" ADD CONSTRAINT "UNIQUE_F33037EE8037D0606D15FFB45EE8A27FD6DE30EE" UNIQUE ("REL_ID_MANAGEDELEMENT_MANAGES_ENODEBFUNCTION");'
);

SELECT ties_data.create_constraint_if_not_exists(
	'o-ran-smo-teiv-ran-logical_ENodeBFunction',
 'FK_ENodeBFunction_REL_FK_realised-by-physicalNetworkAppliance',
 'ALTER TABLE ties_data."o-ran-smo-teiv-ran-logical_ENodeBFunction" ADD CONSTRAINT "FK_ENodeBFunction_REL_FK_realised-by-physicalNetworkAppliance" FOREIGN KEY ("REL_FK_realised-by-physicalNetworkAppliance") REFERENCES ties_data."57a20807ab3f39c86b0b5bf9a819e0881353fa1e" (id) ON DELETE CASCADE;'
);

SELECT ties_data.create_constraint_if_not_exists(
	'o-ran-smo-teiv-ran-logical_ENodeBFunction',
 'UNIQUE_6964DA7D7CC1F79A3DB8B43E5F77E42DF8DFBF73',
 'ALTER TABLE ties_data."o-ran-smo-teiv-ran-logical_ENodeBFunction" ADD CONSTRAINT "UNIQUE_6964DA7D7CC1F79A3DB8B43E5F77E42DF8DFBF73" UNIQUE ("REL_ID_ENODEBFUNCTION_REALISED_BY_PHYSICALNETWORKAPPLIANCE");'
);

SELECT ties_data.create_constraint_if_not_exists(
	'o-ran-smo-teiv-ran-logical_EUtranCell',
 'FK_EUtranCell_REL_FK_grouped-by-sector',
 'ALTER TABLE ties_data."o-ran-smo-teiv-ran-logical_EUtranCell" ADD CONSTRAINT "FK_EUtranCell_REL_FK_grouped-by-sector" FOREIGN KEY ("REL_FK_grouped-by-sector") REFERENCES ties_data."22174a23af5d5a96143c83ddfa78654df0acb697" (id) ON DELETE CASCADE;'
);

SELECT ties_data.create_constraint_if_not_exists(
	'o-ran-smo-teiv-ran-logical_EUtranCell',
 'UNIQUE_EUtranCell_REL_ID_SECTOR_GROUPS_EUTRANCELL',
 'ALTER TABLE ties_data."o-ran-smo-teiv-ran-logical_EUtranCell" ADD CONSTRAINT "UNIQUE_EUtranCell_REL_ID_SECTOR_GROUPS_EUTRANCELL" UNIQUE ("REL_ID_SECTOR_GROUPS_EUTRANCELL");'
);

SELECT ties_data.create_constraint_if_not_exists(
	'o-ran-smo-teiv-ran-logical_EUtranCell',
 'FK_EUtranCell_REL_FK_provided-by-enodebFunction',
 'ALTER TABLE ties_data."o-ran-smo-teiv-ran-logical_EUtranCell" ADD CONSTRAINT "FK_EUtranCell_REL_FK_provided-by-enodebFunction" FOREIGN KEY ("REL_FK_provided-by-enodebFunction") REFERENCES ties_data."o-ran-smo-teiv-ran-logical_ENodeBFunction" (id) ON DELETE CASCADE;'
);

SELECT ties_data.create_constraint_if_not_exists(
	'o-ran-smo-teiv-ran-logical_EUtranCell',
 'UNIQUE_EUtranCell_REL_ID_ENODEBFUNCTION_PROVIDES_EUTRANCELL',
 'ALTER TABLE ties_data."o-ran-smo-teiv-ran-logical_EUtranCell" ADD CONSTRAINT "UNIQUE_EUtranCell_REL_ID_ENODEBFUNCTION_PROVIDES_EUTRANCELL" UNIQUE ("REL_ID_ENODEBFUNCTION_PROVIDES_EUTRANCELL");'
);

SELECT ties_data.create_constraint_if_not_exists(
	'7cd7062ea24531b2f48e4f2fdc51eaf0b82f88c7',
 'FK_B2DDDC542E95DD31826EECEBBF67FD01DAF48833',
 'ALTER TABLE ties_data."7cd7062ea24531b2f48e4f2fdc51eaf0b82f88c7" ADD CONSTRAINT "FK_B2DDDC542E95DD31826EECEBBF67FD01DAF48833" FOREIGN KEY ("aSide_GNBCUCPFunction") REFERENCES ties_data."c4a425179d3089b5288fdf059079d0ea26977f0f" (id) ON DELETE CASCADE;'
);

SELECT ties_data.create_constraint_if_not_exists(
	'7cd7062ea24531b2f48e4f2fdc51eaf0b82f88c7',
 'FK_95C3AD1FCFBD310B9947B9B622CA8E0FC2135DC5',
 'ALTER TABLE ties_data."7cd7062ea24531b2f48e4f2fdc51eaf0b82f88c7" ADD CONSTRAINT "FK_95C3AD1FCFBD310B9947B9B622CA8E0FC2135DC5" FOREIGN KEY ("bSide_CloudNativeApplication") REFERENCES ties_data."e01fcb87ad2c34ce66c34420255e25aaca270e5e" (id) ON DELETE CASCADE;'
);

SELECT ties_data.create_constraint_if_not_exists(
	'c4a425179d3089b5288fdf059079d0ea26977f0f',
 'FK_GNBCUCPFunction_REL_FK_managed-by-managedElement',
 'ALTER TABLE ties_data."c4a425179d3089b5288fdf059079d0ea26977f0f" ADD CONSTRAINT "FK_GNBCUCPFunction_REL_FK_managed-by-managedElement" FOREIGN KEY ("REL_FK_managed-by-managedElement") REFERENCES ties_data."o-ran-smo-teiv-ran-oam_ManagedElement" (id) ON DELETE CASCADE;'
);

SELECT ties_data.create_constraint_if_not_exists(
	'c4a425179d3089b5288fdf059079d0ea26977f0f',
 'UNIQUE_249F73FF1F4316A56DEF4424FA43C2064FFBE4DD',
 'ALTER TABLE ties_data."c4a425179d3089b5288fdf059079d0ea26977f0f" ADD CONSTRAINT "UNIQUE_249F73FF1F4316A56DEF4424FA43C2064FFBE4DD" UNIQUE ("REL_ID_MANAGEDELEMENT_MANAGES_GNBCUCPFUNCTION");'
);

SELECT ties_data.create_constraint_if_not_exists(
	'70a4a84bca01ea022ab24d8cb82422c572922675',
 'FK_F3346189A1BB0DA705219A4136349DF50AE8AA33',
 'ALTER TABLE ties_data."70a4a84bca01ea022ab24d8cb82422c572922675" ADD CONSTRAINT "FK_F3346189A1BB0DA705219A4136349DF50AE8AA33" FOREIGN KEY ("aSide_GNBCUUPFunction") REFERENCES ties_data."8fe520ccd54b8f72ef7b2d3061264ddc2481e4eb" (id) ON DELETE CASCADE;'
);

SELECT ties_data.create_constraint_if_not_exists(
	'70a4a84bca01ea022ab24d8cb82422c572922675',
 'FK_36215EA9FC5F31CC0F131E526A84A54CB006C66B',
 'ALTER TABLE ties_data."70a4a84bca01ea022ab24d8cb82422c572922675" ADD CONSTRAINT "FK_36215EA9FC5F31CC0F131E526A84A54CB006C66B" FOREIGN KEY ("bSide_CloudNativeApplication") REFERENCES ties_data."e01fcb87ad2c34ce66c34420255e25aaca270e5e" (id) ON DELETE CASCADE;'
);

SELECT ties_data.create_constraint_if_not_exists(
	'8fe520ccd54b8f72ef7b2d3061264ddc2481e4eb',
 'FK_GNBCUUPFunction_REL_FK_managed-by-managedElement',
 'ALTER TABLE ties_data."8fe520ccd54b8f72ef7b2d3061264ddc2481e4eb" ADD CONSTRAINT "FK_GNBCUUPFunction_REL_FK_managed-by-managedElement" FOREIGN KEY ("REL_FK_managed-by-managedElement") REFERENCES ties_data."o-ran-smo-teiv-ran-oam_ManagedElement" (id) ON DELETE CASCADE;'
);

SELECT ties_data.create_constraint_if_not_exists(
	'8fe520ccd54b8f72ef7b2d3061264ddc2481e4eb',
 'UNIQUE_BDB349CDF0C4055902881ECCB71F460AE1DD323E',
 'ALTER TABLE ties_data."8fe520ccd54b8f72ef7b2d3061264ddc2481e4eb" ADD CONSTRAINT "UNIQUE_BDB349CDF0C4055902881ECCB71F460AE1DD323E" UNIQUE ("REL_ID_MANAGEDELEMENT_MANAGES_GNBCUUPFUNCTION");'
);

SELECT ties_data.create_constraint_if_not_exists(
	'10484f157f490eb5b27e40dbfaf4d5f2be17c57c',
 'FK_69C6800CC81731E475893CC85582971C7530C98E',
 'ALTER TABLE ties_data."10484f157f490eb5b27e40dbfaf4d5f2be17c57c" ADD CONSTRAINT "FK_69C6800CC81731E475893CC85582971C7530C98E" FOREIGN KEY ("aSide_GNBDUFunction") REFERENCES ties_data."o-ran-smo-teiv-ran-logical_GNBDUFunction" (id) ON DELETE CASCADE;'
);

SELECT ties_data.create_constraint_if_not_exists(
	'10484f157f490eb5b27e40dbfaf4d5f2be17c57c',
 'FK_CA6721EE0944CBBB8E071CEA630162ABD7DFF2DA',
 'ALTER TABLE ties_data."10484f157f490eb5b27e40dbfaf4d5f2be17c57c" ADD CONSTRAINT "FK_CA6721EE0944CBBB8E071CEA630162ABD7DFF2DA" FOREIGN KEY ("bSide_CloudNativeApplication") REFERENCES ties_data."e01fcb87ad2c34ce66c34420255e25aaca270e5e" (id) ON DELETE CASCADE;'
);

SELECT ties_data.create_constraint_if_not_exists(
	'o-ran-smo-teiv-ran-logical_GNBDUFunction',
 'FK_GNBDUFunction_REL_FK_managed-by-managedElement',
 'ALTER TABLE ties_data."o-ran-smo-teiv-ran-logical_GNBDUFunction" ADD CONSTRAINT "FK_GNBDUFunction_REL_FK_managed-by-managedElement" FOREIGN KEY ("REL_FK_managed-by-managedElement") REFERENCES ties_data."o-ran-smo-teiv-ran-oam_ManagedElement" (id) ON DELETE CASCADE;'
);

SELECT ties_data.create_constraint_if_not_exists(
	'o-ran-smo-teiv-ran-logical_GNBDUFunction',
 'UNIQUE_08DFEFAF56EDDE43CBDC336F459D28C6518D3E1D',
 'ALTER TABLE ties_data."o-ran-smo-teiv-ran-logical_GNBDUFunction" ADD CONSTRAINT "UNIQUE_08DFEFAF56EDDE43CBDC336F459D28C6518D3E1D" UNIQUE ("REL_ID_MANAGEDELEMENT_MANAGES_GNBDUFUNCTION");'
);

SELECT ties_data.create_constraint_if_not_exists(
	'c88307168935f02fdecc084ea5040bb9db16c701',
 'FK_LTESectorCarrier_REL_FK_provided-by-enodebFunction',
 'ALTER TABLE ties_data."c88307168935f02fdecc084ea5040bb9db16c701" ADD CONSTRAINT "FK_LTESectorCarrier_REL_FK_provided-by-enodebFunction" FOREIGN KEY ("REL_FK_provided-by-enodebFunction") REFERENCES ties_data."o-ran-smo-teiv-ran-logical_ENodeBFunction" (id) ON DELETE CASCADE;'
);

SELECT ties_data.create_constraint_if_not_exists(
	'c88307168935f02fdecc084ea5040bb9db16c701',
 'UNIQUE_B9770D6C26DDA0173DB9690F6E3B42C111AF26E9',
 'ALTER TABLE ties_data."c88307168935f02fdecc084ea5040bb9db16c701" ADD CONSTRAINT "UNIQUE_B9770D6C26DDA0173DB9690F6E3B42C111AF26E9" UNIQUE ("REL_ID_ENODEBFUNCTION_PROVIDES_LTESECTORCARRIER");'
);

SELECT ties_data.create_constraint_if_not_exists(
	'c88307168935f02fdecc084ea5040bb9db16c701',
 'FK_LTESectorCarrier_REL_FK_used-antennaCapability',
 'ALTER TABLE ties_data."c88307168935f02fdecc084ea5040bb9db16c701" ADD CONSTRAINT "FK_LTESectorCarrier_REL_FK_used-antennaCapability" FOREIGN KEY ("REL_FK_used-antennaCapability") REFERENCES ties_data."88f1bd76c7a935fb505cf235e6819f46c55ec98a" (id) ON DELETE CASCADE;'
);

SELECT ties_data.create_constraint_if_not_exists(
	'c88307168935f02fdecc084ea5040bb9db16c701',
 'UNIQUE_5D5FEB6B4B09D5D42A589753C684994CD0B96E88',
 'ALTER TABLE ties_data."c88307168935f02fdecc084ea5040bb9db16c701" ADD CONSTRAINT "UNIQUE_5D5FEB6B4B09D5D42A589753C684994CD0B96E88" UNIQUE ("REL_ID_LTESECTORCARRIER_USES_ANTENNACAPABILITY");'
);

SELECT ties_data.create_constraint_if_not_exists(
	'c88307168935f02fdecc084ea5040bb9db16c701',
 'FK_LTESectorCarrier_REL_FK_used-by-euTranCell',
 'ALTER TABLE ties_data."c88307168935f02fdecc084ea5040bb9db16c701" ADD CONSTRAINT "FK_LTESectorCarrier_REL_FK_used-by-euTranCell" FOREIGN KEY ("REL_FK_used-by-euTranCell") REFERENCES ties_data."o-ran-smo-teiv-ran-logical_EUtranCell" (id) ON DELETE CASCADE;'
);

SELECT ties_data.create_constraint_if_not_exists(
	'c88307168935f02fdecc084ea5040bb9db16c701',
 'UNIQUE_LTESectorCarrier_REL_ID_EUTRANCELL_USES_LTESECTORCARRIER',
 'ALTER TABLE ties_data."c88307168935f02fdecc084ea5040bb9db16c701" ADD CONSTRAINT "UNIQUE_LTESectorCarrier_REL_ID_EUTRANCELL_USES_LTESECTORCARRIER" UNIQUE ("REL_ID_EUTRANCELL_USES_LTESECTORCARRIER");'
);

SELECT ties_data.create_constraint_if_not_exists(
	'o-ran-smo-teiv-ran-oam_ManagedElement',
 'FK_ManagedElement_REL_FK_deployed-as-cloudNativeSystem',
 'ALTER TABLE ties_data."o-ran-smo-teiv-ran-oam_ManagedElement" ADD CONSTRAINT "FK_ManagedElement_REL_FK_deployed-as-cloudNativeSystem" FOREIGN KEY ("REL_FK_deployed-as-cloudNativeSystem") REFERENCES ties_data."163276fa439cdfccabb80f7acacb6fa638e8d314" (id) ON DELETE CASCADE;'
);

SELECT ties_data.create_constraint_if_not_exists(
	'o-ran-smo-teiv-ran-oam_ManagedElement',
 'UNIQUE_ADD7C124AEF822CB0293FC75E39449DC1AD097E5',
 'ALTER TABLE ties_data."o-ran-smo-teiv-ran-oam_ManagedElement" ADD CONSTRAINT "UNIQUE_ADD7C124AEF822CB0293FC75E39449DC1AD097E5" UNIQUE ("REL_ID_MANAGEDELEMENT_DEPLOYED_AS_CLOUDNATIVESYSTEM");'
);

SELECT ties_data.create_constraint_if_not_exists(
	'o-ran-smo-teiv-ran-logical_NRCellCU',
 'FK_NRCellCU_REL_FK_provided-by-gnbcucpFunction',
 'ALTER TABLE ties_data."o-ran-smo-teiv-ran-logical_NRCellCU" ADD CONSTRAINT "FK_NRCellCU_REL_FK_provided-by-gnbcucpFunction" FOREIGN KEY ("REL_FK_provided-by-gnbcucpFunction") REFERENCES ties_data."c4a425179d3089b5288fdf059079d0ea26977f0f" (id) ON DELETE CASCADE;'
);

SELECT ties_data.create_constraint_if_not_exists(
	'o-ran-smo-teiv-ran-logical_NRCellCU',
 'UNIQUE_NRCellCU_REL_ID_GNBCUCPFUNCTION_PROVIDES_NRCELLCU',
 'ALTER TABLE ties_data."o-ran-smo-teiv-ran-logical_NRCellCU" ADD CONSTRAINT "UNIQUE_NRCellCU_REL_ID_GNBCUCPFUNCTION_PROVIDES_NRCELLCU" UNIQUE ("REL_ID_GNBCUCPFUNCTION_PROVIDES_NRCELLCU");'
);

SELECT ties_data.create_constraint_if_not_exists(
	'o-ran-smo-teiv-ran-logical_NRCellDU',
 'FK_NRCellDU_REL_FK_grouped-by-sector',
 'ALTER TABLE ties_data."o-ran-smo-teiv-ran-logical_NRCellDU" ADD CONSTRAINT "FK_NRCellDU_REL_FK_grouped-by-sector" FOREIGN KEY ("REL_FK_grouped-by-sector") REFERENCES ties_data."22174a23af5d5a96143c83ddfa78654df0acb697" (id) ON DELETE CASCADE;'
);

SELECT ties_data.create_constraint_if_not_exists(
	'o-ran-smo-teiv-ran-logical_NRCellDU',
 'UNIQUE_NRCellDU_REL_ID_SECTOR_GROUPS_NRCELLDU',
 'ALTER TABLE ties_data."o-ran-smo-teiv-ran-logical_NRCellDU" ADD CONSTRAINT "UNIQUE_NRCellDU_REL_ID_SECTOR_GROUPS_NRCELLDU" UNIQUE ("REL_ID_SECTOR_GROUPS_NRCELLDU");'
);

SELECT ties_data.create_constraint_if_not_exists(
	'o-ran-smo-teiv-ran-logical_NRCellDU',
 'FK_NRCellDU_REL_FK_provided-by-gnbduFunction',
 'ALTER TABLE ties_data."o-ran-smo-teiv-ran-logical_NRCellDU" ADD CONSTRAINT "FK_NRCellDU_REL_FK_provided-by-gnbduFunction" FOREIGN KEY ("REL_FK_provided-by-gnbduFunction") REFERENCES ties_data."o-ran-smo-teiv-ran-logical_GNBDUFunction" (id) ON DELETE CASCADE;'
);

SELECT ties_data.create_constraint_if_not_exists(
	'o-ran-smo-teiv-ran-logical_NRCellDU',
 'UNIQUE_NRCellDU_REL_ID_GNBDUFUNCTION_PROVIDES_NRCELLDU',
 'ALTER TABLE ties_data."o-ran-smo-teiv-ran-logical_NRCellDU" ADD CONSTRAINT "UNIQUE_NRCellDU_REL_ID_GNBDUFUNCTION_PROVIDES_NRCELLDU" UNIQUE ("REL_ID_GNBDUFUNCTION_PROVIDES_NRCELLDU");'
);

SELECT ties_data.create_constraint_if_not_exists(
	'39a335dca201ef99ae06f4ffd1908b534f8c6c39',
 'FK_NRSectorCarrier_REL_FK_used-by-nrCellDu',
 'ALTER TABLE ties_data."39a335dca201ef99ae06f4ffd1908b534f8c6c39" ADD CONSTRAINT "FK_NRSectorCarrier_REL_FK_used-by-nrCellDu" FOREIGN KEY ("REL_FK_used-by-nrCellDu") REFERENCES ties_data."o-ran-smo-teiv-ran-logical_NRCellDU" (id) ON DELETE CASCADE;'
);

SELECT ties_data.create_constraint_if_not_exists(
	'39a335dca201ef99ae06f4ffd1908b534f8c6c39',
 'UNIQUE_NRSectorCarrier_REL_ID_NRCELLDU_USES_NRSECTORCARRIER',
 'ALTER TABLE ties_data."39a335dca201ef99ae06f4ffd1908b534f8c6c39" ADD CONSTRAINT "UNIQUE_NRSectorCarrier_REL_ID_NRCELLDU_USES_NRSECTORCARRIER" UNIQUE ("REL_ID_NRCELLDU_USES_NRSECTORCARRIER");'
);

SELECT ties_data.create_constraint_if_not_exists(
	'39a335dca201ef99ae06f4ffd1908b534f8c6c39',
 'FK_NRSectorCarrier_REL_FK_provided-by-gnbduFunction',
 'ALTER TABLE ties_data."39a335dca201ef99ae06f4ffd1908b534f8c6c39" ADD CONSTRAINT "FK_NRSectorCarrier_REL_FK_provided-by-gnbduFunction" FOREIGN KEY ("REL_FK_provided-by-gnbduFunction") REFERENCES ties_data."o-ran-smo-teiv-ran-logical_GNBDUFunction" (id) ON DELETE CASCADE;'
);

SELECT ties_data.create_constraint_if_not_exists(
	'39a335dca201ef99ae06f4ffd1908b534f8c6c39',
 'UNIQUE_872BE05F1989443F2595D99A77BC03733B2D1E2F',
 'ALTER TABLE ties_data."39a335dca201ef99ae06f4ffd1908b534f8c6c39" ADD CONSTRAINT "UNIQUE_872BE05F1989443F2595D99A77BC03733B2D1E2F" UNIQUE ("REL_ID_GNBDUFUNCTION_PROVIDES_NRSECTORCARRIER");'
);

SELECT ties_data.create_constraint_if_not_exists(
	'39a335dca201ef99ae06f4ffd1908b534f8c6c39',
 'FK_NRSectorCarrier_REL_FK_used-antennaCapability',
 'ALTER TABLE ties_data."39a335dca201ef99ae06f4ffd1908b534f8c6c39" ADD CONSTRAINT "FK_NRSectorCarrier_REL_FK_used-antennaCapability" FOREIGN KEY ("REL_FK_used-antennaCapability") REFERENCES ties_data."88f1bd76c7a935fb505cf235e6819f46c55ec98a" (id) ON DELETE CASCADE;'
);

SELECT ties_data.create_constraint_if_not_exists(
	'39a335dca201ef99ae06f4ffd1908b534f8c6c39',
 'UNIQUE_EDF7D5C78EF6505848B1679B714D7831F5863991',
 'ALTER TABLE ties_data."39a335dca201ef99ae06f4ffd1908b534f8c6c39" ADD CONSTRAINT "UNIQUE_EDF7D5C78EF6505848B1679B714D7831F5863991" UNIQUE ("REL_ID_NRSECTORCARRIER_USES_ANTENNACAPABILITY");'
);

SELECT ties_data.create_constraint_if_not_exists(
	'o-ran-smo-teiv-ran-cloud_Namespace',
 'FK_Namespace_REL_FK_deployed-on-nodeCluster',
 'ALTER TABLE ties_data."o-ran-smo-teiv-ran-cloud_Namespace" ADD CONSTRAINT "FK_Namespace_REL_FK_deployed-on-nodeCluster" FOREIGN KEY ("REL_FK_deployed-on-nodeCluster") REFERENCES ties_data."o-ran-smo-teiv-ran-cloud_NodeCluster" (id) ON DELETE CASCADE;'
);

SELECT ties_data.create_constraint_if_not_exists(
	'o-ran-smo-teiv-ran-cloud_Namespace',
 'UNIQUE_Namespace_REL_ID_NAMESPACE_DEPLOYED_ON_NODECLUSTER',
 'ALTER TABLE ties_data."o-ran-smo-teiv-ran-cloud_Namespace" ADD CONSTRAINT "UNIQUE_Namespace_REL_ID_NAMESPACE_DEPLOYED_ON_NODECLUSTER" UNIQUE ("REL_ID_NAMESPACE_DEPLOYED_ON_NODECLUSTER");'
);

SELECT ties_data.create_constraint_if_not_exists(
	'o-ran-smo-teiv-ran-cloud_NodeCluster',
 'FK_NodeCluster_REL_FK_located-at-cloudSite',
 'ALTER TABLE ties_data."o-ran-smo-teiv-ran-cloud_NodeCluster" ADD CONSTRAINT "FK_NodeCluster_REL_FK_located-at-cloudSite" FOREIGN KEY ("REL_FK_located-at-cloudSite") REFERENCES ties_data."o-ran-smo-teiv-ran-cloud_CloudSite" (id) ON DELETE CASCADE;'
);

SELECT ties_data.create_constraint_if_not_exists(
	'o-ran-smo-teiv-ran-cloud_NodeCluster',
 'UNIQUE_NodeCluster_REL_ID_NODECLUSTER_LOCATED_AT_CLOUDSITE',
 'ALTER TABLE ties_data."o-ran-smo-teiv-ran-cloud_NodeCluster" ADD CONSTRAINT "UNIQUE_NodeCluster_REL_ID_NODECLUSTER_LOCATED_AT_CLOUDSITE" UNIQUE ("REL_ID_NODECLUSTER_LOCATED_AT_CLOUDSITE");'
);

SELECT ties_data.create_constraint_if_not_exists(
	'57a20807ab3f39c86b0b5bf9a819e0881353fa1e',
 'FK_PhysicalNetworkAppliance_REL_FK_installed-at-site',
 'ALTER TABLE ties_data."57a20807ab3f39c86b0b5bf9a819e0881353fa1e" ADD CONSTRAINT "FK_PhysicalNetworkAppliance_REL_FK_installed-at-site" FOREIGN KEY ("REL_FK_installed-at-site") REFERENCES ties_data."o-ran-smo-teiv-ran-equipment_Site" (id) ON DELETE CASCADE;'
);

SELECT ties_data.create_constraint_if_not_exists(
	'57a20807ab3f39c86b0b5bf9a819e0881353fa1e',
 'UNIQUE_A9110A77514C472452AC80053A8010FBAF481AD0',
 'ALTER TABLE ties_data."57a20807ab3f39c86b0b5bf9a819e0881353fa1e" ADD CONSTRAINT "UNIQUE_A9110A77514C472452AC80053A8010FBAF481AD0" UNIQUE ("REL_ID_PHYSICALNETWORKAPPLIANCE_INSTALLED_AT_SITE");'
);

SELECT ties_data.create_constraint_if_not_exists(
	'5123d0adfb7b4a04e7f2e5e1783f476ed5cf76f6',
 'PK_ANTENNAMODULE_REALISED_BY_ANTENNAMODULE_id',
 'ALTER TABLE ties_data."5123d0adfb7b4a04e7f2e5e1783f476ed5cf76f6" ADD CONSTRAINT "PK_ANTENNAMODULE_REALISED_BY_ANTENNAMODULE_id" PRIMARY KEY ("id");'
);

SELECT ties_data.create_constraint_if_not_exists(
	'5123d0adfb7b4a04e7f2e5e1783f476ed5cf76f6',
 'FK_ANTENNAMODULE_REALISED_BY_ANTENNAMODULE_aSide_AntennaModule',
 'ALTER TABLE ties_data."5123d0adfb7b4a04e7f2e5e1783f476ed5cf76f6" ADD CONSTRAINT "FK_ANTENNAMODULE_REALISED_BY_ANTENNAMODULE_aSide_AntennaModule" FOREIGN KEY ("aSide_AntennaModule") REFERENCES ties_data."f8caf5ebe876c3001d67efe06e4d83abf0babe31" (id) ON DELETE CASCADE;'
);

SELECT ties_data.create_constraint_if_not_exists(
	'5123d0adfb7b4a04e7f2e5e1783f476ed5cf76f6',
 'FK_ANTENNAMODULE_REALISED_BY_ANTENNAMODULE_bSide_AntennaModule',
 'ALTER TABLE ties_data."5123d0adfb7b4a04e7f2e5e1783f476ed5cf76f6" ADD CONSTRAINT "FK_ANTENNAMODULE_REALISED_BY_ANTENNAMODULE_bSide_AntennaModule" FOREIGN KEY ("bSide_AntennaModule") REFERENCES ties_data."f8caf5ebe876c3001d67efe06e4d83abf0babe31" (id) ON DELETE CASCADE;'
);

SELECT ties_data.create_constraint_if_not_exists(
	'341622dca4e0350289717b52df5883edc3fa0280',
 'PK_2673E8FB17E57FD56D5E897DA13412B9165B90AA',
 'ALTER TABLE ties_data."341622dca4e0350289717b52df5883edc3fa0280" ADD CONSTRAINT "PK_2673E8FB17E57FD56D5E897DA13412B9165B90AA" PRIMARY KEY ("id");'
);

SELECT ties_data.create_constraint_if_not_exists(
	'cd39d44beed963d50df42cd301e63d288f911c97',
 'PK_E3722EAF721B41FACDCF065D2017267CE2C90BED',
 'ALTER TABLE ties_data."cd39d44beed963d50df42cd301e63d288f911c97" ADD CONSTRAINT "PK_E3722EAF721B41FACDCF065D2017267CE2C90BED" PRIMARY KEY ("id");'
);

SELECT ties_data.create_constraint_if_not_exists(
	'cd39d44beed963d50df42cd301e63d288f911c97',
 'FK_00AE9B9921E38ACFEE934695787FA8794817A6ED',
 'ALTER TABLE ties_data."cd39d44beed963d50df42cd301e63d288f911c97" ADD CONSTRAINT "FK_00AE9B9921E38ACFEE934695787FA8794817A6ED" FOREIGN KEY ("aSide_2A2D3374BF907674FA1905478E30ACB8882DC03C") REFERENCES ties_data."341622dca4e0350289717b52df5883edc3fa0280" (id) ON DELETE CASCADE;'
);

SELECT ties_data.create_constraint_if_not_exists(
	'cd39d44beed963d50df42cd301e63d288f911c97',
 'FK_68EED3C83D2C93559F7A61E7D05B4363CDF1DB8F',
 'ALTER TABLE ties_data."cd39d44beed963d50df42cd301e63d288f911c97" ADD CONSTRAINT "FK_68EED3C83D2C93559F7A61E7D05B4363CDF1DB8F" FOREIGN KEY ("bSide_EE6DD4A2CFD743779BBCBFC18FC296EF6D72EB1E") REFERENCES ties_data."341622dca4e0350289717b52df5883edc3fa0280" (id) ON DELETE CASCADE;'
);

SELECT ties_data.create_constraint_if_not_exists(
	'c6f3a3396e9165e886da928c5fe1382fb20dc850',
 'PK_F03D1DD176CD75707BD6217EF652705007C0F272',
 'ALTER TABLE ties_data."c6f3a3396e9165e886da928c5fe1382fb20dc850" ADD CONSTRAINT "PK_F03D1DD176CD75707BD6217EF652705007C0F272" PRIMARY KEY ("id");'
);

SELECT ties_data.create_constraint_if_not_exists(
	'c6f3a3396e9165e886da928c5fe1382fb20dc850',
 'FK_E19DA712FB443E0212578638DF62281CFD6BFA7A',
 'ALTER TABLE ties_data."c6f3a3396e9165e886da928c5fe1382fb20dc850" ADD CONSTRAINT "FK_E19DA712FB443E0212578638DF62281CFD6BFA7A" FOREIGN KEY ("aSide_2A2D3374BF907674FA1905478E30ACB8882DC03C") REFERENCES ties_data."341622dca4e0350289717b52df5883edc3fa0280" (id) ON DELETE CASCADE;'
);

SELECT ties_data.create_constraint_if_not_exists(
	'c6f3a3396e9165e886da928c5fe1382fb20dc850',
 'FK_7772B14325D2340707AF687BF0F70F32914F935D',
 'ALTER TABLE ties_data."c6f3a3396e9165e886da928c5fe1382fb20dc850" ADD CONSTRAINT "FK_7772B14325D2340707AF687BF0F70F32914F935D" FOREIGN KEY ("bSide_EE6DD4A2CFD743779BBCBFC18FC296EF6D72EB1E") REFERENCES ties_data."341622dca4e0350289717b52df5883edc3fa0280" (id) ON DELETE CASCADE;'
);
